$ontext
Code for minimizing GHGs specifically for the DETC-2010 DAC paper

Code to run 1-vehicle model
MINLP model to determine (1) vehicle type; (2) PHEV design; (3) allocations
Optimzation of PHEV design and allocations for total cost / person-day
Modeling NHTS driving patterns using exponential distribution
3 binary variable sets: z_j, y_k, q_o, j={1,2,3}, k={1,2,3}, o={1,2,3}
*
filename code:
P: Use Peterson's (A123) battery degradation curve (2009)
L: dictator assigns each driver leased battery
B: dictator assigns each driver buy-lease battery scenario
---
Code: CS Norman Shiau
Carnegie Mellon University, Pittsburgh, PA
----
Update 12/13/2009
Changes: (1) HEV NiMH battery cost $600/kWh
         (2) PHEV Li-ion battery cost $400/kWh
         (3) Acceleration constraint 11 seconds
---
Update: 1/31/2010 - updated for IDETC paper
   put GHGs as main objective function for the DAC optimization paper
---
Update: 4/10/2010 - second submission of IDETC-DAC paper
   (1) Updated the exp distribution coefficient to NHTS 2009 weighted data
   (2) Added battery charging efficient effBAT (95%)
   (3) Updated US avg. elec. emission factor to 0.69/kWh

$offtext


PARAMETERS
  k       Exp dist coefficeint on the NHTS 2009 weighted data /0.029595/,
  dMAX    Maximum range in driving data 200 miles /200/,
  vGAS    LC-GHGs of gasoline per gallon 11.34 kg per gal /11.34/,
* The US avg. elec. emission factor = 0.69*1.09(loss) = 0.7521
  vELEC   LC-GHGs of eletricity (0.67*1.09) kg per kWh /0.7521/,
  vVEH    LC-GHGs of base vehicle manufacturing /8500/,
  cGAS    2008 average gas price $ per gallon /3.30/,
  cELEC   2008 average elec price 11.36 cents per kWh /0.1136/,
  cVEH    vehicle base cost /11183/,
  cLiIon  Li-ion battery cost $450 per kWh /400/,
  cNiMH   NiMH   battery cost $600 per kWh /600/,
  vLiIon  LC-GHGs of Li-ion battery 120 kg-CO2-eq per kWh /120/,
  vNiMH   LC-GHGs of NiMH   battery 230 kg-CO2-eq per kWh /230/,
  carbon  carbon allowance price per kg-CO2-eq /0.0/,
* battery cell nominal volatge = 3.6 volt
* battery cell capacity = 6 Ah
* energy capacity = 6*3.6 = 21.6 Wh per cell
  effCHG   Charging efficiency between socket to battery /0.88/,
  effBAT   Charging efficiency in the battery /0.95/,
  alphaDRV REC slope on driving  in the Peterson model /3.458e-2/,
  alphaCHG REC slope on charging in the Peterson model /1.720e-2/,
  kappa    energy capacity kWh per cell /21.6e-3/,
  sLIFE    vehicle life VMT 150k miles  /150000/,
  rEOL     relative energy capacity fade for end-of-life /0.2/,
  FEM, FSM,
* HEV with NiMH battery
  HEVmpg mpg for HEV /60.1/,
  CVmpg  mpg for CV  /29.5/,
  cHEV   manufacturing cost of HEV,
  cCV    manufacturing cost of CV,
  vHEV   LC-GHG emissions of HEV,
  vCV    LC-GHG emissions of CV,
*
* metamodel coefficients for efficiency (electricity) in CD mode
        aED1 /0.007852585706/,
        aED2 /0.154288922601/,
        aED3 /0.352933730854/,
        aED4 /-0.004816150342/,
        aED5 /-0.005479431340/,
        aED6 /-0.025338082140/,
        aED7 /0.000212011360/,
        aED8 /-0.057118497613/,
        aED9 /-0.042739509965/,
        aED10 /-0.015830972520/,
        aED11 /-0.001028174658/,
        aED12 /-0.805369774847/,
        aED13 /-0.655580550098/,
        aED14 /0.057270405947/,
        aED15 /0.079730362360/,
        aED16 /0.342091579946/,
        aED17 /-0.191345333621/,
        aED18 /1.188971392024/,
        aED19 /-0.346682012779/,
        aED20 /4.960068215723/,
* metamodel coefficients for efficiency (gasoline) in CS mode
        aES1 /2.214067463410/,
        aES2 /1.086659693552/,
        aES3 /5.577874978662/,
        aES4 /-0.815241697738/,
        aES5 /0.509578110533/,
        aES6 /1.561758113326/,
        aES7 /2.212321055022/,
        aES8 /-0.612567680918/,
        aES9 /0.254008083604/,
        aES10 /-0.159429747244/,
        aES11 /-8.905599398536/,
        aES12 /-6.095001164559/,
        aES13 /-15.207539664993/,
        aES14 /0.089172114876/,
        aES15 /-3.273526677614/,
        aES16 /2.498376358946/,
        aES17 /2.621894664006/,
        aES18 /9.284846067558/,
        aES19 /5.837143728557/,
        aES20 /57.679680208231/,
* aAD = metamodel coefficients for PHEV acceleration in CD mode
        aAD1 /1.456640469666/,
        aAD2 /-5.495718264905/,
        aAD3 /-28.456261951645/,
        aAD4 /0.912917970314/,
        aAD5 /-0.881199206310/,
        aAD6 /-1.049763024383/,
        aAD7 /-0.308107344863/,
        aAD8 /2.043536297441/,
        aAD9 /15.609611231641/,
        aAD10 /0.336486837518/,
        aAD11 /-4.634160849469/,
        aAD12 /31.478262635483/,
        aAD13 /34.016843490037/,
        aAD14 /1.153148892739/,
        aAD15 /1.168601192983/,
        aAD16 /-32.056936006397/,
        aAD17 /3.405095041238/,
        aAD18 /-54.472915571467/,
        aAD19 /9.569879128240/,
        aAD20 /44.230616625681/,
* aAS = metamodel coefficients for PHEV acceleration in CS mode
        aAS1 /3.334445194766/,
        aAS2 /-2.265666208775/,
        aAS3 /-20.256566414583/,
        aAS4 /0.413782262402/,
        aAS5 /-3.523622273943/,
        aAS6 /-0.285910055687/,
        aAS7 /-10.110726634622/,
        aAS8 /1.950721968140/,
        aAS9 /10.308512463418/,
        aAS10 /5.808426325827/,
        aAS11 /-6.932398033967/,
        aAS12 /15.800194269340/,
        aAS13 /39.197963873266/,
        aAS14 /7.900706395772/,
        aAS15 /6.581860921560/,
        aAS16 /-30.119438887106/,
        aAS17 /-6.733798415788/,
        aAS18 /-26.385308892431/,
        aAS19 /-4.098268423019/,
        aAS20 /32.102172356117/,
* coefficients for final SOC after running 4 continuous US06 cycles
        aU1 /.0/,
        aU2 /.0/,
        aU3 /.0/,
        aU4 /.0/,
        aU5 /.0/,
        aU6 /.0/,
        aU7 /.0/,
        aU8 /.0/,
        aU9 /.0/,
        aU10 /.0/,
        aU11 /-0.194075741585/,
        aU12 /-0.004843420334/,
        aU13 /0.047366866350/,
        aU14 /0.000094029979/,
        aU15 /0.011329651793/,
        aU16 /-0.001017352942/,
        aU17 /0.382275988592/,
        aU18 /0.019484588535/,
        aU19 /-0.077357069039/,
        aU20 /0.140278656706/,
* coefficients for energy processed in one UDDS cycle in CD mode
        aWD1 /.0/,
        aWD2 /.0/,
        aWD3 /.0/,
        aWD4 /.0/,
        aWD5 /.0/,
        aWD6 /.0/,
        aWD7 /.0/,
        aWD8 /.0/,
        aWD9 /.0/,
        aWD10 /.0/,
        aWD11 /0.010073140669/,
        aWD12 /0.011394190823/,
        aWD13 /0.052910213683/,
        aWD14 /0.000159410872/,
        aWD15 /0.008036404292/,
        aWD16 /-0.003423392047/,
        aWD17 /0.097124049148/,
        aWD18 /0.038291803440/,
        aWD19 /0.370440556286/,
        aWD20 /2.196152004583/,
* coefficients for energy processed in one UDDS cycle in CS mode
        aWS1 /.0/,
        aWS2 /.0/,
        aWS3 /.0/,
        aWS4 /.0/,
        aWS5 /.0/,
        aWS6 /.0/,
        aWS7 /.0/,
        aWS8 /.0/,
        aWS9 /.0/,
        aWS10 /.0/,
        aWS11 /0.46598008632/,
        aWS12 /-0.00797004615/,
        aWS13 /-0.01779288613/,
        aWS14 /-0.01429434551/,
        aWS15 /-0.03832188467/,
        aWS16 /0.00970510229/,
        aWS17 /-0.88981702163/,
        aWS18 /0.07730602595/,
        aWS19 /0.39988032723/,
        aWS20 /1.44118818458/;
* calculate the GHGs of HEV and CV
* HEV: 57kW Atkinson engine, 52kW PM-type motor, 1.31 kWh NiMH battery pack
vHEV=vVEH+1.31*vNiMH;
* CV: inline-4 engine 126kW
vCV =vVEH;

BINARY VARIABLES
   z11,z12,z13, y11,y12,y13, q11,q12,q13,
   t1p  vehcle type PHEV for section 1,
   t1h  vehcle type HEV  for section 1,
   t1c  vehcle type CV   for section 1;
POSITIVE VARIABLES
   xE1      PEHV#1 engine scaling variable,
   xM1      PEHV#1 motor scaling variable,
   xB1      PEHV#1 battery size scaling variable,
   xS1      PEHV#1 battery design swing,
   tAD1     PHEV#1 0-60 acceleration in CD mode,
   tAS1     PHEV#1 0-60 acceleration in CS mode,
   socU1    PHEV#1 final SOC after running 4 US06,
   effCD1   PHEV#1 efficicncy in CD mode,
   effCS1   PHEV#1 efficiency in CS mode,
   muCD1    PHEV#1 energy processed in CD mode,
   muCS1    PHEV#1 energy processed in CS mode,
   AER1     PHEV#1 AER,
   sT1      PHEV#1 switching point in buy-lease scenario,
   FEA1, FSA1, FET1, FST1;

VARIABLES
   ghgs1    PHEV#1 GHG emissions;

EQUATIONS
   f_AER1, f_effCD1, f_effCS1, f_tAD1, f_tAS1, f_SU1, c_tAD1, c_tAS1, c_SU1,
   f_FEA1,f_FSA1,f_muCD1,f_muCS1, f_sT1, f_FET1, f_FST1,
   c_zz1,c_z11,c_z12a,c_z12b,c_z13, c_yy1,c_y11,c_y12a,c_y12b,c_y13, c_qq1, c_q11, c_q12a, c_q12b, c_q13,
   c_yq11, c_yq13, c_zyq1_212, c_zyq1_312, c_zyq1_322,
   f_ghgs1, c_t1;
*
f_AER1 .. AER1 =E= kappa*1000*xB1*xS1*effCD1;
f_FEA1 .. FEA1 =E= 1/k-exp(-1*k*AER1)*(AER1+1/k);
f_FSA1 .. FSA1 =E= 1-exp(-1*k*AER1);
f_sT1  .. sT1  =E= sLIFE*AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)
                   /(0.2*(1000*xB1)*(1000*kappa)-alphaDRV*muCS1*sLIFE);
*
f_effCD1 .. effCD1 =E= aED1*xE1**3+aED2*xM1**3+aED3*xB1**3+aED4*xE1**2*xM1+aED5*xE1*xM1**2+aED6*xE1**2*xB1
     + aED7*xE1*xB1**2+aED8*xM1**2*xB1+aED9*xM1*xB1**2+aED10*xE1*xM1*xB1
     + aED11*xE1**2+aED12*xM1**2+aED13*xB1**2+aED14*xE1*xM1+aED15*xE1*xB1+aED16*xM1*xB1
     + aED17*xE1+aED18*xM1+aED19*xB1+aED20;
f_effCS1 .. effCS1 =E= aES1*xE1**3+aES2*xM1**3+aES3*xB1**3+aES4*xE1**2*xM1+aES5*xE1*xM1**2+aES6*xE1**2*xB1
     + aES7*xE1*xB1**2+aES8*xM1**2*xB1+aES9*xM1*xB1**2+aES10*xE1*xM1*xB1
     + aES11*xE1**2+aES12*xM1**2+aES13*xB1**2+aES14*xE1*xM1+aES15*xE1*xB1+aES16*xM1*xB1
     + aES17*xE1+aES18*xM1+aES19*xB1+aES20;
f_tAD1 .. tAD1 =e= aAD1*xE1**3+aAD2*xM1**3+aAD3*xB1**3+aAD4*xE1**2*xM1+aAD5*xE1*xM1**2+aAD6*xE1**2*xB1
       + aAD7*xE1*xB1**2+aAD8*xM1**2*xB1+aAD9*xM1*xB1**2+aAD10*xE1*xM1*xB1
       + aAD11*xE1**2+aAD12*xM1**2+aAD13*xB1**2+aAD14*xE1*xM1+aAD15*xE1*xB1+aAD16*xM1*xB1
       + aAD17*xE1+aAD18*xM1+aAD19*xB1+aAD20;
f_tAS1 .. tAS1 =e= aAS1*xE1**3+aAS2*xM1**3+aAS3*xB1**3+aAS4*xE1**2*xM1+aAS5*xE1*xM1**2+aAS6*xE1**2*xB1
       + aAS7*xE1*xB1**2+aAS8*xM1**2*xB1+aAS9*xM1*xB1**2+aAS10*xE1*xM1*xB1
       + aAS11*xE1**2+aAS12*xM1**2+aAS13*xB1**2+aAS14*xE1*xM1+aAS15*xE1*xB1+aAS16*xM1*xB1
       + aAS17*xE1+aAS18*xM1+aAS19*xB1+aAS20;
f_SU1 .. socU1 =e= aU1*xE1**3+aU2*xM1**3+aU3*xB1**3+aU4*xE1**2*xM1+aU5*xE1*xM1**2+aU6*xE1**2*xB1
       + aU7*xE1*xB1**2+aU8*xM1**2*xB1+aU9*xM1*xB1**2+aU10*xE1*xM1*xB1
       + aU11*xE1**2+aU12*xM1**2+aU13*xB1**2+aU14*xE1*xM1+aU15*xE1*xB1+aU16*xM1*xB1
       + aU17*xE1+aU18*xM1+aU19*xB1+aU20;
f_muCD1 .. muCD1 =E= (aWD1*xE1**3+aWD2*xM1**3+aWD3*xB1**3+aWD4*xE1**2*xM1+aWD5*xE1*xM1**2+aWD6*xE1**2*xB1
     + aWD7*xE1*xB1**2+aWD8*xM1**2*xB1+aWD9*xM1*xB1**2+aWD10*xE1*xM1*xB1
     + aWD11*xE1**2+aWD12*xM1**2+aWD13*xB1**2+aWD14*xE1*xM1+aWD15*xE1*xB1+aWD16*xM1*xB1
     + aWD17*xE1+aWD18*xM1+aWD19*xB1+aWD20)/7.4226;
f_muCS1 .. muCS1 =E= (aWS1*xE1**3+aWS2*xM1**3+aWS3*xB1**3+aWS4*xE1**2*xM1+aWS5*xE1*xM1**2+aWS6*xE1**2*xB1
     + aWS7*xE1*xB1**2+aWS8*xM1**2*xB1+aWS9*xM1*xB1**2+aWS10*xE1*xM1*xB1
     + aWS11*xE1**2+aWS12*xM1**2+aWS13*xB1**2+aWS14*xE1*xM1+aWS15*xE1*xB1+aWS16*xM1*xB1
     + aWS17*xE1+aWS18*xM1+aWS19*xB1+aWS20)/7.4226;
*
c_tAD1 .. tAD1 =l= 11;
c_tAS1 .. tAS1 =l= 11;
c_SU1 .. socU1 =g= 0.32;
*
f_FET1 .. FET1 =E= 1/k-exp(-1*k*sT1)*(sT1+1/k);
f_FST1 .. FST1 =E= 1-exp(-1*k*sT1);
*
FEM=1/k-exp(-1*k*dMAX)*(dMAX+1/k);
FSM=1-exp(-1*k*dMAX);
*
*
f_ghgs1 .. ghgs1 =e=
* if vehicle#1 is CV
   t1c*( (vCV/sLIFE+vGAS/CVmpg )*FEM )
* if vehicle#1 is HEV (with a 1.31 kWh NiMH battery)
  +t1h*( (vHEV/sLIFE+vGAS/HEVmpg)*FEM )
* if vehcile#1 is PHEV
* average vehicle ghgs (same across all conditions)
  +t1p*( vVEH/sLIFE*FEM
* operating ghgs (depends on AER conditions z only)
    +z11*( vGAS/effCS1*FEM+AER1*(vELEC/effCD1/effCHG-vGAS/effCS1)*FSM )
    +z12*( vELEC/effCD1/effCHG*FEA1+vGAS/effCS1*(FEM-FEA1)+AER1*(vELEC/effCD1/effCHG-vGAS/effCS1)*(FSM-FSA1) )
    +z13*( vELEC/effCD1/effCHG*FEM )
* average battery ghgs for buy-lease scenario (depends on z, y and q)
* Remark A (112 and jk3)
    +(y11*q12+q13)*( 1000*xB1*kappa*vLiIon/sLIFE*FEM )
* Remark B (122)
    +z11*y12*q12*( vLiIon/200*(alphaDRV*muCS1*FET1+AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*FST1)
                    +1000*xB1*kappa*vLiIon/sLIFE*(FEM-FET1) )
* Remark C (222)
    +z12*y12*q12*( vLiIon/200*( (alphaDRV*muCD1+alphaCHG/effCD1/effBAT)*FEA1+alphaDRV*muCS1*(FET1-FEA1)
                            +AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*(FST1-FSA1) )
                +1000*xB1*kappa*vLiIon/sLIFE*(FEM-FET1) )
* Remark D (132 and 1k1)
    +(z11*y13*q12+z11*q11)*( vLiIon/200*(alphaDRV*muCS1*FEM+
                 AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*FSM )  )
* Remark E (232 and 2k1)
    +(z12*y13*q12+z12*q11)*( vLiIon/200*( (alphaDRV*muCD1+alphaCHG/effCD1/effBAT)*FEA1+alphaDRV*muCS1*(FEM-FEA1)
                +AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*(FSM-FSA1) ) )
* Remark F (332 and 3k1)
    +(z13*y13*q12+z13*q11)*vLiIon/200*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT)*FEM  );
*
c_t1  .. t1p+t1h+t1c =e= 1;
*
* constraints for binary variable sets
c_zz1 .. z11+z12+z13 =e= 1;
c_yy1 .. y11+y12+y13 =e= 1;
c_qq1 .. q11+q12+q13 =e= 1;
*
* constraints on z
c_z11  .. z11*(AER1-0) =l= 0;
c_z12a .. z12*(AER1-0) =g= 0;
c_z12b .. z12*(AER1-dmax) =l= 0;
c_z13  .. z13*(AER1-dmax) =g= 0;
*
* constraints on y (they only matter when q_2=1)
c_y11  .. q12*y11*(sT1-0) =l= 0;
c_y12a .. q12*y12*(sT1-0) =g= 0;
c_y12b .. q12*y12*(sT1-dmax) =l= 0;
c_y13  .. q12*y13*(sT1-dmax) =g= 0;
*
* conditional constraints on q
c_q11  .. q11*(1e6*xB1*kappa*rEOL/(alphaDRV*muCS1)-sLIFE) =l= 0;
c_q12a .. q12*(1e6*xB1*kappa*rEOL/(alphaDRV*muCS1)-sLIFE) =g= 0;
c_q13  .. q13*(sLIFE-1e6*xB1*kappa*rEOL/(alphaDRV*muCD1+alphaCHG/effCD1)) =l= 0;
c_q12b .. q12*(sLIFE-1e6*xB1*kappa*rEOL/(alphaDRV*muCD1+alphaCHG/effCD1)) =g= 0;
*
* constraints to exclude infeasible zyq combinations (212),(312),(322)
c_zyq1_212 .. z12+y11+q12 =l= 2;
c_zyq1_312 .. z13+y11+q12 =l= 2;
c_zyq1_322 .. z13+y12+q12 =l= 2;
*
* when (q_1=1 or q_3=1), force y1=1 to save computational time
c_yq13  .. q13*(y11-1) =g= 0;
c_yq11  .. q11*(y11-1) =g= 0;

*xE1.fx=0.8298; xM1.fx=1.3624; xB1.fx=0.4466;
**********************************************
xE1.lo = 30/57;    xE1.up=60/57;    xE1.l=1;
xM1.lo = 50/52;    xM1.up=110/52;   xM1.l=1;
xB1.lo = 0.2;      xB1.up=1.0;      xB1.l=0.5;
xS1.lo = 0.0;      xS1.up=0.8;      xS1.fx=0.8;
*
effCD1.lo=4.9;  effCD1.up=5.5;
effCS1.lo=55;   effCS1.up=63;
muCD1.lo=2.2/7.4226;   muCD1.up=3.0/7.4226;
muCS1.lo=1.0/7.4226;   muCS1.up=1.7/7.4226;
socU1.lo=0.26;  socU1.up=0.35;
*
muCD1.l=(aWD1*xE1.l**3+aWD2*xM1.l**3+aWD3*xB1.l**3+aWD4*xE1.l**2*xM1.l+aWD5*xE1.l*xM1.l**2+aWD6*xE1.l**2*xB1.l
     + aWD7*xE1.l*xB1.l**2+aWD8*xM1.l**2*xB1.l+aWD9*xM1.l*xB1.l**2+aWD10*xE1.l*xM1.l*xB1.l
     + aWD11*xE1.l**2+aWD12*xM1.l**2+aWD13*xB1.l**2+aWD14*xE1.l*xM1.l+aWD15*xE1.l*xB1.l+aWD16*xM1.l*xB1.l
     + aWD17*xE1.l+aWD18*xM1.l+aWD19*xB1.l+aWD20)/7.4226;
muCS1.l=(aWS1*xE1.l**3+aWS2*xM1.l**3+aWS3*xB1.l**3+aWS4*xE1.l**2*xM1.l+aWS5*xE1.l*xM1.l**2+aWS6*xE1.l**2*xB1.l
     + aWS7*xE1.l*xB1.l**2+aWS8*xM1.l**2*xB1.l+aWS9*xM1.l*xB1.l**2+aWS10*xE1.l*xM1.l*xB1.l
     + aWS11*xE1.l**2+aWS12*xM1.l**2+aWS13*xB1.l**2+aWS14*xE1.l*xM1.l+aWS15*xE1.l*xB1.l+aWS16*xM1.l*xB1.l
     + aWS17*xE1.l+aWS18*xM1.l+aWS19*xB1.l+aWS20)/7.4226;
effCD1.l = aED1*xE1.l**3+aED2*xM1.l**3+aED3*xB1.l**3+aED4*xE1.l**2*xM1.l+aED5*xE1.l*xM1.l**2+aED6*xE1.l**2*xB1.l
     + aED7*xE1.l*xB1.l**2+aED8*xM1.l**2*xB1.l+aED9*xM1.l*xB1.l**2+aED10*xE1.l*xM1.l*xB1.l
     + aED11*xE1.l**2+aED12*xM1.l**2+aED13*xB1.l**2+aED14*xE1.l*xM1.l+aED15*xE1.l*xB1.l+aED16*xM1.l*xB1.l
     + aED17*xE1.l+aED18*xM1.l+aED19*xB1.l+aED20;
effCS1.l = aES1*xE1.l**3+aES2*xM1.l**3+aES3*xB1.l**3+aES4*xE1.l**2*xM1.l+aES5*xE1.l*xM1.l**2+aES6*xE1.l**2*xB1.l
     + aES7*xE1.l*xB1.l**2+aES8*xM1.l**2*xB1.l+aES9*xM1.l*xB1.l**2+aES10*xE1.l*xM1.l*xB1.l
     + aES11*xE1.l**2+aES12*xM1.l**2+aES13*xB1.l**2+aES14*xE1.l*xM1.l+aES15*xE1.l*xB1.l+aES16*xM1.l*xB1.l
     + aES17*xE1.l+aES18*xM1.l+aES19*xB1.l+aES20;
socU1.l = aU1*xE1.l**3+aU2*xM1.l**3+aU3*xB1.l**3+aU4*xE1.l**2*xM1.l+aU5*xE1.l*xM1.l**2+aU6*xE1.l**2*xB1.l
       + aU7*xE1.l*xB1.l**2+aU8*xM1.l**2*xB1.l+aU9*xM1.l*xB1.l**2+aU10*xE1.l*xM1.l*xB1.l
       + aU11*xE1.l**2+aU12*xM1.l**2+aU13*xB1.l**2+aU14*xE1.l*xM1.l+aU15*xE1.l*xB1.l+aU16*xM1.l*xB1.l
       + aU17*xE1.l+aU18*xM1.l+aU19*xB1.l+aU20;
tAD1.l = aAD1*xE1.l**3+aAD2*xM1.l**3+aAD3*xB1.l**3+aAD4*xE1.l**2*xM1.l+aAD5*xE1.l*xM1.l**2+aAD6*xE1.l**2*xB1.l
       + aAD7*xE1.l*xB1.l**2+aAD8*xM1.l**2*xB1.l+aAD9*xM1.l*xB1.l**2+aAD10*xE1.l*xM1.l*xB1.l
       + aAD11*xE1.l**2+aAD12*xM1.l**2+aAD13*xB1.l**2+aAD14*xE1.l*xM1.l+aAD15*xE1.l*xB1.l+aAD16*xM1.l*xB1.l
       + aAD17*xE1.l+aAD18*xM1.l+aAD19*xB1.l+aAD20;
tAS1.l = aAS1*xE1.l**3+aAS2*xM1.l**3+aAS3*xB1.l**3+aAS4*xE1.l**2*xM1.l+aAS5*xE1.l*xM1.l**2+aAS6*xE1.l**2*xB1.l
       + aAS7*xE1.l*xB1.l**2+aAS8*xM1.l**2*xB1.l+aAS9*xM1.l*xB1.l**2+aAS10*xE1.l*xM1.l*xB1.l
       + aAS11*xE1.l**2+aAS12*xM1.l**2+aAS13*xB1.l**2+aAS14*xE1.l*xM1.l+aAS15*xE1.l*xB1.l+aAS16*xM1.l*xB1.l
       + aAS17*xE1.l+aAS18*xM1.l+aAS19*xB1.l+aAS20;
*
AER1.l=kappa*1000*xB1.l*xS1.l*effCD1.l; AER1.up=90;
*
FEA1.l=1/k-exp(-1*k*AER1.l)*(AER1.l+1/k); FEA1.up=26;
FSA1.l=1-exp(-1*k*AER1.l); FSA1.up=1;
*
sT1.l =sLIFE*AER1.l*(alphaDRV*muCD1.l+alphaCHG/effCD1.l-alphaDRV*muCS1.l)
                   /(0.2*kappa*1e6*xB1.l-alphaDRV*muCS1.l*sLIFE);
sT1.up=200;
*
FET1.l=1/k-exp(-1*k*sT1.l)*(sT1.l+1/k); FET1.up=34.1;
FST1.l=1-exp(-1*k*sT1.l); FST1.up=1;
*
tAD1.up=13;    tAD1.lo=6;
tAS1.up=13;    tAS1.lo=6;
*
z11.l=0; z12.l=1; z13.l=0;
y11.l=0; y12.l=1; y13.l=0;
q11.l=0; q12.l=1; q13.l=0;
*
* note: exclude CV and fix VEH#1=PHEV to save computational time
t1p.fx=1;  t1h.fx=0;  t1c.fx=0;
*

model PHEV /all/;
$onecho > baron.opt
nlpsol=4
MaxTime=45000
$offecho
PHEV.optfile=1;
option MINLP=baron;
solve PHEV using MINLP min ghgs1;

****** post-process
****** display in the log file
file log / '' /;
put log;
put ' ' /;
put 'Optimal 1-vehicle designs and allocations for min GHGs' /;
put 'Peterson battery model with buy-lease scenario (PB)' /;
put '------------------------------------------------' /;
put 'Parameters:' /;
put 'Li-ion Battery GHGs = ',(vLiIon):4:0,' kg-CO2-eq/kWh' /;
put '  NiMH Battery GHGs = ',(vNiMH):4:0,' kg-CO2-eq/kWh' /;
put '        Gas GHGs = ',(vGAS):5:2, ' kg-CO2-eq/gal' /;
put 'Electricity GHGs = ',(vELEC):6:4,' kg-CO2-eq/kWh' /;
put '------------------------------------------------' /;
if (t1p.l=1,
   put 'VEHICLE-1 is a PHEV',(AER1.l):3:0 /;
   put '---------------------' /;
   put '   All Elec Range    AER = ',(AER1.l):6:2,' miles' /;
   put '   Engine scale       xE = ',(xE1.l):6:4,' (',(xE1.l*57):5:1,' kW)'/;
   put '   Motor scale        xM = ',(xM1.l):6:4,' (',(xM1.l*52):5:1,' kW)'/;
   put '   Battery scale      xB = ',(xB1.l):6:4,' (',(xB1.l*1000):4:0,' cells)'/;
   put '   Design swing       xS = ',(xS1.l):6:4 /;
   put '   CD efficiency  eff.CD = ',(effCD1.l):6:2,' mile/kWh' /;
   put '   CS efficiency  eff.CS = ',(effCS1.l):6:2,' mile/gal' /;
   put '   CD acceleration  t.CD = ',(tAD1.l):6:2,' secs' /;
   put '   CS acceleration  t.CS = ',(tAS1.l):6:2,' secs' /;
   put '   Battery energy cap.   = ',(xB1.l*1000*kappa):6:3, ' kWh' /;
   put '   Final SOC after 4US06 = ',(SOCU1.l):6:3 /;
   put '   VEH-BAT life point sT = ',(sT1.l):7:3,' miles'/;
elseif (t1h.l=1),
   put 'VEHICLE-1 is a HEV' /;
   put '---------------------' /;
elseif (t1c.l=1),
   put 'VEHICLE-1 is a CV' /;
   put '---------------------' /;
else
   put 'VEHICLE-1 is not identified' /;
) ;
put '   Total GHG emissions     = ',(ghgs1.l):9:6,' kg-CO2-eq/person-day'/;
put '------------------------------------------------' /;

put ' ' /;
put (xE1.l):16:12 /;
put (xM1.l):16:12 /;
put (xB1.l):16:12 /;
put (xS1.l):16:12 /;
put ' ' /;

