$ontext
Code to run 3-vehicle model for minimizing GHG emissions
MINLP model to determine (1) vehicle type; (2) PHEV design; (3) allocations
Optimzation of PHEV design and allocations for total cost / person-day
Modeling NHTS driving patterns using exponential distribution
3 binary variable sets: z_j, y_k, q_o, j={1,2,3}, k={1,2,3}, o={1,2,3}
*
filename code:
P: Use Peterson's (A123) battery degradation curve (2009)
L: dictator assigns each driver leased battery
B: dictator assigns each driver buy-lease battery scenario

Code: CS Norman Shiau
Carnegie Mellon University, Pittsburgh, PA
Latest update: Jan 2010
Changes: HEV NiMH battery cost $600/kWh
         PHEV Li-ion battery cost $400/kWh
         Acceleration constraint 11 seconds
---
Update: 1/31/2010 - updated for IDETC paper
   put GHGs as main objective function for the DAC optimization paper
---
Update: 4/10/2010 - second submission of IDETC-DAC paper
  (1) Updated the exp distribution coefficient to NHTS 2009 weighted data
  (2) Added battery charging efficient effBAT (95%)
  (3) Updated US avg. elec. emission factor to 0.69/kWh

$offtext


PARAMETERS
  k       Exp dist coefficeint on the NHTS 2009 weighted data /0.029595/,
  dMAX     Maximum range in driving data 200 miles /200/,
  vGAS     LC-GHGs of gasoline per gallon 11.34 kg per gal /11.34/,
* The US avg. elec. emission factor = 0.69*1.09(loss) = 0.7521
  vELEC   LC-GHGs of eletricity (0.67*1.09) kg per kWh /0.7521/,
  vVEH     LC-GHGs of base vehicle manufacturing /8500/,
  cGAS     2008 average gas price $ per gallon /3.30/,
  cELEC    2008 average elec price 11.36 cents per kWh /0.1136/,
  cVEH     vehicle base cost /11183/,
  cLiIon     Li-ion battery cost $450 per kWh /400/,
  cNiMH    NiMH   battery cost $600 per kWh /600/,
  vLiIon   LC-GHGs of Li-ion battery 120 kg-CO2-eq per kWh /120/,
  vNiMH    LC-GHGs of NiMH   battery 230 kg-CO2-eq per kWh /230/,
  carbon   carbon allowance price per kg-CO2-eq /0.0/,
* battery cell nominal volatge = 3.6 volt
* battery cell capacity = 6 Ah
* energy capacity = 6*3.6 = 21.6 Wh per cell
  effCHG   Charging efficiency /0.88/,
  effBAT   Charging efficiency in the battery /0.95/,
  alphaDRV REC slope on driving in Peterson model  /0.03458/,
  alphaCHG REC slope on charging in Peterson model /0.01720/,
  kappa    energy capacity kWh per cell /21.6e-3/,
  sLIFE    vehicle life VMT 150k miles  /150000/,
  rEOL     relative energy capacity fade for end-of-life /0.2/,
  FEM, FSM,
* HEV with NiMH battery
  HEVmpg mpg for HEV /60.1/,
  CVmpg  mpg for CV  /29.5/,
  cHEV   manufacturing cost of HEV,
  cCV    manufacturing cost of CV,
  vHEV   LC-GHG emissions of HEV,
  vCV    LC-GHG emissions of CV,
*
* metamodel coefficients for efficiency (electricity) in CD mode
        aED1 /0.007852585706/,
        aED2 /0.154288922601/,
        aED3 /0.352933730854/,
        aED4 /-0.004816150342/,
        aED5 /-0.005479431340/,
        aED6 /-0.025338082140/,
        aED7 /0.000212011360/,
        aED8 /-0.057118497613/,
        aED9 /-0.042739509965/,
        aED10 /-0.015830972520/,
        aED11 /-0.001028174658/,
        aED12 /-0.805369774847/,
        aED13 /-0.655580550098/,
        aED14 /0.057270405947/,
        aED15 /0.079730362360/,
        aED16 /0.342091579946/,
        aED17 /-0.191345333621/,
        aED18 /1.188971392024/,
        aED19 /-0.346682012779/,
        aED20 /4.960068215723/,
* metamodel coefficients for efficiency (gasoline) in CS mode
        aES1 /2.214067463410/,
        aES2 /1.086659693552/,
        aES3 /5.577874978662/,
        aES4 /-0.815241697738/,
        aES5 /0.509578110533/,
        aES6 /1.561758113326/,
        aES7 /2.212321055022/,
        aES8 /-0.612567680918/,
        aES9 /0.254008083604/,
        aES10 /-0.159429747244/,
        aES11 /-8.905599398536/,
        aES12 /-6.095001164559/,
        aES13 /-15.207539664993/,
        aES14 /0.089172114876/,
        aES15 /-3.273526677614/,
        aES16 /2.498376358946/,
        aES17 /2.621894664006/,
        aES18 /9.284846067558/,
        aES19 /5.837143728557/,
        aES20 /57.679680208231/,
* aAD = metamodel coefficients for PHEV acceleration in CD mode
        aAD1 /1.456640469666/,
        aAD2 /-5.495718264905/,
        aAD3 /-28.456261951645/,
        aAD4 /0.912917970314/,
        aAD5 /-0.881199206310/,
        aAD6 /-1.049763024383/,
        aAD7 /-0.308107344863/,
        aAD8 /2.043536297441/,
        aAD9 /15.609611231641/,
        aAD10 /0.336486837518/,
        aAD11 /-4.634160849469/,
        aAD12 /31.478262635483/,
        aAD13 /34.016843490037/,
        aAD14 /1.153148892739/,
        aAD15 /1.168601192983/,
        aAD16 /-32.056936006397/,
        aAD17 /3.405095041238/,
        aAD18 /-54.472915571467/,
        aAD19 /9.569879128240/,
        aAD20 /44.230616625681/,
* aAS = metamodel coefficients for PHEV acceleration in CS mode
        aAS1 /3.334445194766/,
        aAS2 /-2.265666208775/,
        aAS3 /-20.256566414583/,
        aAS4 /0.413782262402/,
        aAS5 /-3.523622273943/,
        aAS6 /-0.285910055687/,
        aAS7 /-10.110726634622/,
        aAS8 /1.950721968140/,
        aAS9 /10.308512463418/,
        aAS10 /5.808426325827/,
        aAS11 /-6.932398033967/,
        aAS12 /15.800194269340/,
        aAS13 /39.197963873266/,
        aAS14 /7.900706395772/,
        aAS15 /6.581860921560/,
        aAS16 /-30.119438887106/,
        aAS17 /-6.733798415788/,
        aAS18 /-26.385308892431/,
        aAS19 /-4.098268423019/,
        aAS20 /32.102172356117/,
* coefficients for final SOC after running 4 continuous US06 cycles
        aU1 /.0/,
        aU2 /.0/,
        aU3 /.0/,
        aU4 /.0/,
        aU5 /.0/,
        aU6 /.0/,
        aU7 /.0/,
        aU8 /.0/,
        aU9 /.0/,
        aU10 /.0/,
        aU11 /-0.194075741585/,
        aU12 /-0.004843420334/,
        aU13 /0.047366866350/,
        aU14 /0.000094029979/,
        aU15 /0.011329651793/,
        aU16 /-0.001017352942/,
        aU17 /0.382275988592/,
        aU18 /0.019484588535/,
        aU19 /-0.077357069039/,
        aU20 /0.140278656706/,
* coefficients for energy processed in one UDDS cycle in CD mode
        aWD1 /.0/,
        aWD2 /.0/,
        aWD3 /.0/,
        aWD4 /.0/,
        aWD5 /.0/,
        aWD6 /.0/,
        aWD7 /.0/,
        aWD8 /.0/,
        aWD9 /.0/,
        aWD10 /.0/,
        aWD11 /0.010073140669/,
        aWD12 /0.011394190823/,
        aWD13 /0.052910213683/,
        aWD14 /0.000159410872/,
        aWD15 /0.008036404292/,
        aWD16 /-0.003423392047/,
        aWD17 /0.097124049148/,
        aWD18 /0.038291803440/,
        aWD19 /0.370440556286/,
        aWD20 /2.196152004583/,
* coefficients for energy processed in one UDDS cycle in CS mode
        aWS1 /.0/,
        aWS2 /.0/,
        aWS3 /.0/,
        aWS4 /.0/,
        aWS5 /.0/,
        aWS6 /.0/,
        aWS7 /.0/,
        aWS8 /.0/,
        aWS9 /.0/,
        aWS10 /.0/,
        aWS11 /0.46598008632/,
        aWS12 /-0.00797004615/,
        aWS13 /-0.01779288613/,
        aWS14 /-0.01429434551/,
        aWS15 /-0.03832188467/,
        aWS16 /0.00970510229/,
        aWS17 /-0.88981702163/,
        aWS18 /0.07730602595/,
        aWS19 /0.39988032723/,
        aWS20 /1.44118818458/;
* calculate the costs of HEV and CV
* HEV: 57kW Atkinson engine, 52kW PM-type motor, 1.31 kWh NiMH battery pack
cHEV=cVEH+(17.8*57 +650)+(26.6*52+520)+1.31*cNiMH;
vHEV=vVEH+1.31*vNiMH;
* CV: inline-4 engine 126kW
cCV =cVEH+(17.8*126+650);
vCV =vVEH;

BINARY VARIABLES
   z11,z12,z13, y11,y12,y13, q11,q12,q13,
   z21,z22,z23, y21,y22,y23, q21,q22,q23,
   z31,z32,z33, y31,y32,y33, q31,q32,q33,
   t1p vehcle type PHEV for section 1,
   t1h vehcle type HEV  for section 1,
   t1c vehcle type CV   for section 1,
   t2p vehcle type PHEV for section 2,
   t2h vehcle type HEV  for section 2,
   t2c vehcle type CV   for section 2,
   t3p vehcle type PHEV for section 3,
   t3h vehcle type HEV  for section 3,
   t3c vehcle type CV   for section 3;

POSITIVE VARIABLES
   xE1      PEHV#1 engine scaling variable,
   xM1      PEHV#1 motor scaling variable,
   xB1      PEHV#1 battery size scaling variable,
   xS1      PEHV#1 battery design swing,
   tAD1     PHEV#1 0-60 acceleration in CD mode,
   tAS1     PHEV#1 0-60 acceleration in CS mode,
   socU1    PHEV#1 final SOC after running 4 US06,
   effCD1   PHEV#1 efficicncy in CD mode,
   effCS1   PHEV#1 efficiency in CS mode,
   ghgs1    PHEV#1 lifecycle GHG emissions,
   muCD1    PHEV#1 energy processed in CD mode,
   muCS1    PHEV#1 energy processed in CS mode,
   AER1     PHEV#1 AER,
   sT1      PHEV#1 switching point for at-least-1 case,
   FEA1, FSA1, FET1, FST1,
*
   xE2      PEHV#2 engine scaling variable,
   xM2      PEHV#2 motor scaling variable,
   xB2      PEHV#2 battery size scaling variable,
   xS2      PEHV#2 battery design swing,
   tAD2     PHEV#2 0-60 acceleration in CD mode,
   tAS2     PHEV#2 0-60 acceleration in CS mode,
   socU2    PHEV#2 final SOC after running 4 US06,
   effCD2   PHEV#2 efficicncy in CD mode,
   effCS2   PHEV#2 efficiency in CS mode,
   ghgs2    PHEV#2 lifecycle GHG emissions,
   muCD2    PHEV#2 energy processed in CD mode,
   muCS2    PHEV#2 energy processed in CS mode,
   AER2     PHEV#2 AER,
   sT2      PHEV#2 switching point for at-least-1 case,
   FEA2, FSA2, FET2, FST2,
*
   xE3      PEHV#3 engine scaling variable,
   xM3      PEHV#3 motor scaling variable,
   xB3      PEHV#3 battery size scaling variable,
   xS3      PEHV#3 battery design swing,
   tAD3     PHEV#3 0-60 acceleration in CD mode,
   tAS3     PHEV#3 0-60 acceleration in CS mode,
   socU3    PHEV#3 final SOC after running 4 US06,
   effCD3   PHEV#3 efficicncy in CD mode,
   effCS3   PHEV#3 efficiency in CS mode,
   ghgs3    PHEV#3 lifecycle GHG emissions,
   muCD3    PHEV#3 energy processed in CD mode,
   muCS3    PHEV#3 energy processed in CS mode,
   AER3     PHEV#3 AER,
   sT3      PHEV#3 switching point for at-least-1 case,
   FEA3, FSA3, FET3, FST3,
*
   sC1  cutoff distance #1,
   sC2  cutoff distance #2,
   FEC1, FSC1,
   FEC2, FSC2;

VARIABLES
   ghgstot  total lifecycle GHG emissions of 3 PHEVs;

EQUATIONS
   f_AER1, f_effCD1, f_effCS1, f_tAD1, f_tAS1, f_SU1, c_tAD1, c_tAS1, c_SU1,
   f_AER2, f_effCD2, f_effCS2, f_tAD2, f_tAS2, f_SU2, c_tAD2, c_tAS2, c_SU2,
   f_AER3, f_effCD3, f_effCS3, f_tAD3, f_tAS3, f_SU3, c_tAD3, c_tAS3, c_SU3,
   f_FEA1,f_FSA1,f_muCD1,f_muCS1, f_sT1, f_FET1, f_FST1,
   f_FEA2,f_FSA2,f_muCD2,f_muCS2, f_sT2, f_FET2, f_FST2,
   f_FEA3,f_FSA3,f_muCD3,f_muCS3, f_sT3, f_FET3, f_FST3,
   c_zz1,c_z11,c_z12a,c_z12b,c_z13, c_yy1,c_y11,c_y12a,c_y12b,c_y13, c_qq1, c_q11, c_q12a, c_q12b, c_q13,
   c_zz2,c_z21,c_z22a,c_z22b,c_z23, c_yy2,c_y21,c_y22a,c_y22b,c_y23, c_qq2, c_q21, c_q22a, c_q22b, c_q23,
   c_zz3,c_z31,c_z32a,c_z32b,c_z33, c_yy3,c_y31,c_y32a,c_y32b,c_y33, c_qq3, c_q31, c_q32a, c_q32b, c_q33,
   c_yq11, c_yq13, c_zyq1_212, c_zyq1_312, c_zyq1_322,
   c_yq21, c_yq23, c_zyq2_212, c_zyq2_312, c_zyq2_322,
   c_yq31, c_yq33, c_zyq3_212, c_zyq3_312, c_zyq3_322,
   f_ghgs1, c_t1,
   f_ghgs2, c_t2,
   f_ghgs3, c_t3,
   f_FEC1, f_FSC1,
   f_FEC2, f_FSC2,
   c_sc12,
   f_ghgstot;
*
f_AER1 .. AER1 =E= kappa*1000*xB1*xS1*effCD1;
f_FEA1 .. FEA1 =E= 1/k-exp(-1*k*AER1)*(AER1+1/k);
f_FSA1 .. FSA1 =E= 1-exp(-1*k*AER1);
f_sT1  .. sT1  =E= sLIFE*AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)
                   /(0.2*(1000*xB1)*21.6-alphaDRV*muCS1*sLIFE);
*
f_effCD1 .. effCD1 =E= aED1*xE1**3+aED2*xM1**3+aED3*xB1**3+aED4*xE1**2*xM1+aED5*xE1*xM1**2+aED6*xE1**2*xB1
     + aED7*xE1*xB1**2+aED8*xM1**2*xB1+aED9*xM1*xB1**2+aED10*xE1*xM1*xB1
     + aED11*xE1**2+aED12*xM1**2+aED13*xB1**2+aED14*xE1*xM1+aED15*xE1*xB1+aED16*xM1*xB1
     + aED17*xE1+aED18*xM1+aED19*xB1+aED20;
f_effCS1 .. effCS1 =E= aES1*xE1**3+aES2*xM1**3+aES3*xB1**3+aES4*xE1**2*xM1+aES5*xE1*xM1**2+aES6*xE1**2*xB1
     + aES7*xE1*xB1**2+aES8*xM1**2*xB1+aES9*xM1*xB1**2+aES10*xE1*xM1*xB1
     + aES11*xE1**2+aES12*xM1**2+aES13*xB1**2+aES14*xE1*xM1+aES15*xE1*xB1+aES16*xM1*xB1
     + aES17*xE1+aES18*xM1+aES19*xB1+aES20;
f_tAD1 .. tAD1 =e= aAD1*xE1**3+aAD2*xM1**3+aAD3*xB1**3+aAD4*xE1**2*xM1+aAD5*xE1*xM1**2+aAD6*xE1**2*xB1
       + aAD7*xE1*xB1**2+aAD8*xM1**2*xB1+aAD9*xM1*xB1**2+aAD10*xE1*xM1*xB1
       + aAD11*xE1**2+aAD12*xM1**2+aAD13*xB1**2+aAD14*xE1*xM1+aAD15*xE1*xB1+aAD16*xM1*xB1
       + aAD17*xE1+aAD18*xM1+aAD19*xB1+aAD20;
f_tAS1 .. tAS1 =e= aAS1*xE1**3+aAS2*xM1**3+aAS3*xB1**3+aAS4*xE1**2*xM1+aAS5*xE1*xM1**2+aAS6*xE1**2*xB1
       + aAS7*xE1*xB1**2+aAS8*xM1**2*xB1+aAS9*xM1*xB1**2+aAS10*xE1*xM1*xB1
       + aAS11*xE1**2+aAS12*xM1**2+aAS13*xB1**2+aAS14*xE1*xM1+aAS15*xE1*xB1+aAS16*xM1*xB1
       + aAS17*xE1+aAS18*xM1+aAS19*xB1+aAS20;
f_SU1 .. socU1 =e= aU1*xE1**3+aU2*xM1**3+aU3*xB1**3+aU4*xE1**2*xM1+aU5*xE1*xM1**2+aU6*xE1**2*xB1
       + aU7*xE1*xB1**2+aU8*xM1**2*xB1+aU9*xM1*xB1**2+aU10*xE1*xM1*xB1
       + aU11*xE1**2+aU12*xM1**2+aU13*xB1**2+aU14*xE1*xM1+aU15*xE1*xB1+aU16*xM1*xB1
       + aU17*xE1+aU18*xM1+aU19*xB1+aU20;
f_muCD1 .. muCD1 =E= (aWD1*xE1**3+aWD2*xM1**3+aWD3*xB1**3+aWD4*xE1**2*xM1+aWD5*xE1*xM1**2+aWD6*xE1**2*xB1
     + aWD7*xE1*xB1**2+aWD8*xM1**2*xB1+aWD9*xM1*xB1**2+aWD10*xE1*xM1*xB1
     + aWD11*xE1**2+aWD12*xM1**2+aWD13*xB1**2+aWD14*xE1*xM1+aWD15*xE1*xB1+aWD16*xM1*xB1
     + aWD17*xE1+aWD18*xM1+aWD19*xB1+aWD20)/7.4226;
f_muCS1 .. muCS1 =E= (aWS1*xE1**3+aWS2*xM1**3+aWS3*xB1**3+aWS4*xE1**2*xM1+aWS5*xE1*xM1**2+aWS6*xE1**2*xB1
     + aWS7*xE1*xB1**2+aWS8*xM1**2*xB1+aWS9*xM1*xB1**2+aWS10*xE1*xM1*xB1
     + aWS11*xE1**2+aWS12*xM1**2+aWS13*xB1**2+aWS14*xE1*xM1+aWS15*xE1*xB1+aWS16*xM1*xB1
     + aWS17*xE1+aWS18*xM1+aWS19*xB1+aWS20)/7.4226;
*
f_AER2 .. AER2 =E= kappa*1000*xB2*xS2*effCD2;
f_FEA2 .. FEA2 =E= 1/k-exp(-1*k*AER2)*(AER2+1/k);
f_FSA2 .. FSA2 =E= 1-exp(-1*k*AER2);
f_sT2  .. sT2  =E= sLIFE*AER2*(alphaDRV*muCD2+alphaCHG/effCD2/effBAT-alphaDRV*muCS2)
                    /(0.2*(1000*xB2)*21.6-alphaDRV*muCS2*sLIFE);
*
f_effCD2 .. effCD2 =E= aED1*xE2**3+aED2*xM2**3+aED3*xB2**3+aED4*xE2**2*xM2+aED5*xE2*xM2**2+aED6*xE2**2*xB2
     + aED7*xE2*xB2**2+aED8*xM2**2*xB2+aED9*xM2*xB2**2+aED10*xE2*xM2*xB2
     + aED11*xE2**2+aED12*xM2**2+aED13*xB2**2+aED14*xE2*xM2+aED15*xE2*xB2+aED16*xM2*xB2
     + aED17*xE2+aED18*xM2+aED19*xB2+aED20;
f_effCS2 .. effCS2 =E= aES1*xE2**3+aES2*xM2**3+aES3*xB2**3+aES4*xE2**2*xM2+aES5*xE2*xM2**2+aES6*xE2**2*xB2
     + aES7*xE2*xB2**2+aES8*xM2**2*xB2+aES9*xM2*xB2**2+aES10*xE2*xM2*xB2
     + aES11*xE2**2+aES12*xM2**2+aES13*xB2**2+aES14*xE2*xM2+aES15*xE2*xB2+aES16*xM2*xB2
     + aES17*xE2+aES18*xM2+aES19*xB2+aES20;
f_tAD2 .. tAD2 =e= aAD1*xE2**3+aAD2*xM2**3+aAD3*xB2**3+aAD4*xE2**2*xM2+aAD5*xE2*xM2**2+aAD6*xE2**2*xB2
       + aAD7*xE2*xB2**2+aAD8*xM2**2*xB2+aAD9*xM2*xB2**2+aAD10*xE2*xM2*xB2
       + aAD11*xE2**2+aAD12*xM2**2+aAD13*xB2**2+aAD14*xE2*xM2+aAD15*xE2*xB2+aAD16*xM2*xB2
       + aAD17*xE2+aAD18*xM2+aAD19*xB2+aAD20;
f_tAS2 .. tAS2 =e= aAS1*xE2**3+aAS2*xM2**3+aAS3*xB2**3+aAS4*xE2**2*xM2+aAS5*xE2*xM2**2+aAS6*xE2**2*xB2
       + aAS7*xE2*xB2**2+aAS8*xM2**2*xB2+aAS9*xM2*xB2**2+aAS10*xE2*xM2*xB2
       + aAS11*xE2**2+aAS12*xM2**2+aAS13*xB2**2+aAS14*xE2*xM2+aAS15*xE2*xB2+aAS16*xM2*xB2
       + aAS17*xE2+aAS18*xM2+aAS19*xB2+aAS20;
f_SU2 .. socU2 =e= aU1*xE2**3+aU2*xM2**3+aU3*xB2**3+aU4*xE2**2*xM2+aU5*xE2*xM2**2+aU6*xE2**2*xB2
       + aU7*xE2*xB2**2+aU8*xM2**2*xB2+aU9*xM2*xB2**2+aU10*xE2*xM2*xB2
       + aU11*xE2**2+aU12*xM2**2+aU13*xB2**2+aU14*xE2*xM2+aU15*xE2*xB2+aU16*xM2*xB2
       + aU17*xE2+aU18*xM2+aU19*xB2+aU20;
f_muCD2 .. muCD2 =E= (aWD1*xE2**3+aWD2*xM2**3+aWD3*xB2**3+aWD4*xE2**2*xM2+aWD5*xE2*xM2**2+aWD6*xE2**2*xB2
     + aWD7*xE2*xB2**2+aWD8*xM2**2*xB2+aWD9*xM2*xB2**2+aWD10*xE2*xM2*xB2
     + aWD11*xE2**2+aWD12*xM2**2+aWD13*xB2**2+aWD14*xE2*xM2+aWD15*xE2*xB2+aWD16*xM2*xB2
     + aWD17*xE2+aWD18*xM2+aWD19*xB2+aWD20)/7.4226;
f_muCS2 .. muCS2 =E= (aWS1*xE2**3+aWS2*xM2**3+aWS3*xB2**3+aWS4*xE2**2*xM2+aWS5*xE2*xM2**2+aWS6*xE2**2*xB2
     + aWS7*xE2*xB2**2+aWS8*xM2**2*xB2+aWS9*xM2*xB2**2+aWS10*xE2*xM2*xB2
     + aWS11*xE2**2+aWS12*xM2**2+aWS13*xB2**2+aWS14*xE2*xM2+aWS15*xE2*xB2+aWS16*xM2*xB2
     + aWS17*xE2+aWS18*xM2+aWS19*xB2+aWS20)/7.4226;
*
f_AER3 .. AER3 =E= kappa*1000*xB3*xS3*effCD3;
f_FEA3 .. FEA3 =E= 1/k-exp(-1*k*AER3)*(AER3+1/k);
f_FSA3 .. FSA3 =E= 1-exp(-1*k*AER3);
f_sT3  .. sT3  =E= sLIFE*AER3*(alphaDRV*muCD3+alphaCHG/effCD3/effBAT-alphaDRV*muCS3)
                    /(0.2*(1000*xB3)*21.6-alphaDRV*muCS3*sLIFE);
*
f_effCD3 .. effCD3 =E= aED1*xE3**3+aED2*xM3**3+aED3*xB3**3+aED4*xE3**2*xM3+aED5*xE3*xM3**2+aED6*xE3**2*xB3
     + aED7*xE3*xB3**2+aED8*xM3**2*xB3+aED9*xM3*xB3**2+aED10*xE3*xM3*xB3
     + aED11*xE3**2+aED12*xM3**2+aED13*xB3**2+aED14*xE3*xM3+aED15*xE3*xB3+aED16*xM3*xB3
     + aED17*xE3+aED18*xM3+aED19*xB3+aED20;
f_effCS3 .. effCS3 =E= aES1*xE3**3+aES2*xM3**3+aES3*xB3**3+aES4*xE3**2*xM3+aES5*xE3*xM3**2+aES6*xE3**2*xB3
     + aES7*xE3*xB3**2+aES8*xM3**2*xB3+aES9*xM3*xB3**2+aES10*xE3*xM3*xB3
     + aES11*xE3**2+aES12*xM3**2+aES13*xB3**2+aES14*xE3*xM3+aES15*xE3*xB3+aES16*xM3*xB3
     + aES17*xE3+aES18*xM3+aES19*xB3+aES20;
f_tAD3 .. tAD3 =e= aAD1*xE3**3+aAD2*xM3**3+aAD3*xB3**3+aAD4*xE3**2*xM3+aAD5*xE3*xM3**2+aAD6*xE3**2*xB3
       + aAD7*xE3*xB3**2+aAD8*xM3**2*xB3+aAD9*xM3*xB3**2+aAD10*xE3*xM3*xB3
       + aAD11*xE3**2+aAD12*xM3**2+aAD13*xB3**2+aAD14*xE3*xM3+aAD15*xE3*xB3+aAD16*xM3*xB3
       + aAD17*xE3+aAD18*xM3+aAD19*xB3+aAD20;
f_tAS3 .. tAS3 =e= aAS1*xE3**3+aAS2*xM3**3+aAS3*xB3**3+aAS4*xE3**2*xM3+aAS5*xE3*xM3**2+aAS6*xE3**2*xB3
       + aAS7*xE3*xB3**2+aAS8*xM3**2*xB3+aAS9*xM3*xB3**2+aAS10*xE3*xM3*xB3
       + aAS11*xE3**2+aAS12*xM3**2+aAS13*xB3**2+aAS14*xE3*xM3+aAS15*xE3*xB3+aAS16*xM3*xB3
       + aAS17*xE3+aAS18*xM3+aAS19*xB3+aAS20;
f_SU3 .. socU3 =e= aU1*xE3**3+aU2*xM3**3+aU3*xB3**3+aU4*xE3**2*xM3+aU5*xE3*xM3**2+aU6*xE3**2*xB3
       + aU7*xE3*xB3**2+aU8*xM3**2*xB3+aU9*xM3*xB3**2+aU10*xE3*xM3*xB3
       + aU11*xE3**2+aU12*xM3**2+aU13*xB3**2+aU14*xE3*xM3+aU15*xE3*xB3+aU16*xM3*xB3
       + aU17*xE3+aU18*xM3+aU19*xB3+aU20;
f_muCD3 .. muCD3 =E= (aWD1*xE3**3+aWD2*xM3**3+aWD3*xB3**3+aWD4*xE3**2*xM3+aWD5*xE3*xM3**2+aWD6*xE3**2*xB3
     + aWD7*xE3*xB3**2+aWD8*xM3**2*xB3+aWD9*xM3*xB3**2+aWD10*xE3*xM3*xB3
     + aWD11*xE3**2+aWD12*xM3**2+aWD13*xB3**2+aWD14*xE3*xM3+aWD15*xE3*xB3+aWD16*xM3*xB3
     + aWD17*xE3+aWD18*xM3+aWD19*xB3+aWD20)/7.4226;
f_muCS3 .. muCS3 =E= (aWS1*xE3**3+aWS2*xM3**3+aWS3*xB3**3+aWS4*xE3**2*xM3+aWS5*xE3*xM3**2+aWS6*xE3**2*xB3
     + aWS7*xE3*xB3**2+aWS8*xM3**2*xB3+aWS9*xM3*xB3**2+aWS10*xE3*xM3*xB3
     + aWS11*xE3**2+aWS12*xM3**2+aWS13*xB3**2+aWS14*xE3*xM3+aWS15*xE3*xB3+aWS16*xM3*xB3
     + aWS17*xE3+aWS18*xM3+aWS19*xB3+aWS20)/7.4226;
*
c_tAD1 .. tAD1  =l= 11.0001;
c_tAS1 .. tAS1  =l= 11.0001;
c_SU1  .. socU1 =g= 0.32-0.0001;
c_tAD2 .. tAD2  =l= 11.0001;
c_tAS2 .. tAS2  =l= 11.0001;
c_SU2  .. socU2 =g= 0.32-0.0001;
c_tAD3 .. tAD3  =l= 11.0001;
c_tAS3 .. tAS3  =l= 11.0001;
c_SU3  .. socU3 =g= 0.32-0.0001;
*
f_FEC1 .. FEC1 =E= 1/k-exp(-1*k*SC1)*(SC1+1/k);
f_FSC1 .. FSC1 =E= 1-exp(-1*k*SC1);
f_FEC2 .. FEC2 =E= 1/k-exp(-1*k*SC2)*(SC2+1/k);
f_FSC2 .. FSC2 =E= 1-exp(-1*k*SC2);
*
f_FET1 .. FET1 =E= 1/k-exp(-1*k*sT1)*(sT1+1/k);
f_FST1 .. FST1 =E= 1-exp(-1*k*sT1);
*
f_FET2 .. FET2 =E= 1/k-exp(-1*k*sT2)*(sT2+1/k);
f_FST2 .. FST2 =E= 1-exp(-1*k*sT2);
*
f_FET3 .. FET3 =E= 1/k-exp(-1*k*sT3)*(sT3+1/k);
f_FST3 .. FST3 =E= 1-exp(-1*k*sT3);
*
FEM=1/k-exp(-1*k*dMAX)*(dMAX+1/k);
FSM=1-exp(-1*k*dMAX);
*
f_ghgs1 .. ghgs1 =e=
* if vehicle#1 is CV
   t1c*( ( vCV/sLIFE+vGAS/CVmpg )*FEC1 )
* if vehicle#1 is HEV
  +t1h*( (vHEV/sLIFE+vGAS/HEVmpg)*FEC1 )
* if vehcile#1 is PHEV
* average vehicle ghgs (the same across all conditions)
  +t1p*( vVEH/sLIFE*FEC1
* operating ghgs (depends on AER conditions z only)
    +z11*( vGAS/effCS1*FEC1+AER1*(vELEC/effCD1/effCHG-vGAS/effCS1)*FSC1 )
    +z12*( vELEC/effCD1/effCHG*FEA1+vGAS/effCS1*(FEC1-FEA1)+AER1*(vELEC/effCD1/effCHG-vGAS/effCS1)*(FSC1-FSA1) )
    +z13*( vELEC/effCD1/effCHG*FEC1 )
* average battery ghgs for buy-lease scenario (depends on z, y and q)
* Remark A (112 and jk3)
    +(y11*q12+q13)*( 1000*xB1*kappa*vLiIon/sLIFE*FEC1 )
* Remark B (122)
    +z11*y12*q12*( vLiIon/200*(alphaDRV*muCS1*FET1+AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*FST1)
                    +1000*xB1*kappa*vLiIon/sLIFE*(FEC1-FET1) )
* Remark C (222)
    +z12*y12*q12*( vLiIon/200*( (alphaDRV*muCD1+alphaCHG/effCD1/effBAT)*FEA1+alphaDRV*muCS1*(FET1-FEA1)
                            +AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*(FST1-FSA1) )
                +1000*xB1*kappa*vLiIon/sLIFE*(FEC1-FET1) )
* Remark D (132 and 1k1)
    +(z11*y13*q12+z11*q11)*( vLiIon/200*(alphaDRV*muCS1*FEC1+
                 AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*FSC1 )  )
* Remark E (232 and 2k1)
    +(z12*y13*q12+z12*q11)*( vLiIon/200*( (alphaDRV*muCD1+alphaCHG/effCD1/effBAT)*FEA1+alphaDRV*muCS1*(FEC1-FEA1)
                +AER1*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT-alphaDRV*muCS1)*(FSC1-FSA1) ) )
* Remark F (332 and 3k1)
    +(z13*y13*q12+z13*q11)*vLiIon/200*(alphaDRV*muCD1+alphaCHG/effCD1/effBAT)*FEC1  );
*******
f_ghgs2 .. ghgs2 =e=
* if vehicle#2 is CV
   t2c*( ( vCV/sLIFE+vGAS/CVmpg) *(FEC2-FEC1) )
* if vehicle#2 is HEV
  +t2h*( (vHEV/sLIFE+vGAS/HEVmpg)*(FEC2-FEC1) )
* if vehcile#2 is PHEV
* average vehicle ghgs (the same across all conditions)
  +t2p*( vVEH/sLIFE*(FEC2-FEC1)
* operating ghgs (depends on AER conditions z only)
      +z21*( vGAS/effCS2*(FEC2-FEC1)+AER2*(vELEC/effCD2/effCHG-vGAS/effCS2)*(FSC2-FSC1) )
      +z22*( vELEC/effCD2/effCHG*(FEA2-FEC1)+vGAS/effCS2*(FEC2-FEA2)+AER2*(vELEC/effCD2/effCHG-vGAS/effCS2)*(FSC2-FSA2) )
      +z23*( vELEC/effCD2/effCHG*(FEC2-FEC1) )
* average battery ghgs for buy-lease scenario (depends on z, y and q)
* Remark A (112 and jk3)
    +(y21*q22+q23)*( 1000*xB2*kappa*vLiIon/sLIFE*(FEC2-FEC1) )
* Remark B (122)
    +z21*y22*q22*( vLiIon/200*(alphaDRV*muCS2*(FET2-FEC1)+AER2*(alphaDRV*muCD2+alphaCHG/effCD2/effBAT-alphaDRV*muCS2)*(FST2-FSC1))
                   +1000*xB2*kappa*vLiIon/sLIFE*(FEC2-FET2))
* Remark C (222)
    +z22*y22*q22*( vLiIon/200*( (alphaDRV*muCD2+alphaCHG/effCD2/effBAT)*(FEA2-FEC1)+alphaDRV*muCS2*(FET2-FEA2)
                               +AER2*(alphaDRV*muCD2+alphaCHG/effCD2/effBAT-alphaDRV*muCS2)*(FST2-FSA2) )
                   +1000*xB2*kappa*vLiIon/sLIFE*(FEC2-FET2)  )
* Remark D (132 and 1k1)
    +(z21*y23*q22+z21*q21)*( vLiIon/200*(alphaDRV*muCS2*(FEC2-FEC1)+
                             AER2*(alphaDRV*muCD2+alphaCHG/effCD2/effBAT-alphaDRV*muCS2)*(FSC2-FSC1) )  )
* Remark E (232 and 2k1)
    +(z22*y23*q22+z22*q21)*( vLiIon/200*( (alphaDRV*muCD2+alphaCHG/effCD2/effBAT)*(FEA2-FEC1)
                            +alphaDRV*muCS2*(FEC2-FEA2)
                            +AER2*(alphaDRV*muCD2+alphaCHG/effCD2/effBAT-alphaDRV*muCS2)*(FSC2-FSA2) ) )
* Remark F (332 and 3k1)
    +(z23*y23*q22+z23*q21)*vLiIon/200*(alphaDRV*muCD2+alphaCHG/effCD2/effBAT)*(FEC2-FEC1)  );
*******
f_ghgs3 .. ghgs3 =e=
* if vehicle#2 is CV
   t3c*( ( vCV/sLIFE+vGAS/CVmpg) *(FEM-FEC2) )
* if vehicle#2 is HEV
  +t3h*( (vHEV/sLIFE+vGAS/HEVmpg)*(FEM-FEC2) )
* if vehcile#2 is PHEV
* average vehicle ghgs (the same across all conditions)
  +t3p*( vVEH/sLIFE*(FEM-FEC2)
* operating ghgs (depends on AER conditions z only)
      +z31*( vGAS/effCS3*(FEM-FEC2)+AER3*(vELEC/effCD3/effCHG-vGAS/effCS3)*(FSM-FSC2) )
      +z32*( vELEC/effCD3/effCHG*(FEA3-FEC2)+vGAS/effCS3*(FEM-FEA3)+AER3*(vELEC/effCD3/effCHG-vGAS/effCS3)*(FSM-FSA3) )
      +z33*( vELEC/effCD3/effCHG*(FEM-FEC2) )
* average battery ghgs for buy-lease scenario (depends on z, y and q)
* Remark A (112 and jk3)
    +(y31*q32+q33)*( 1000*xB3*kappa*vLiIon/sLIFE*(FEM-FEC2) )
* Remark B (122)
    +z31*y32*q32*( vLiIon/200*(alphaDRV*muCS3*(FET3-FEC2)+AER3*(alphaDRV*muCD3+alphaCHG/effCD3/effBAT-alphaDRV*muCS3)*(FST3-FSC2))
                   +1000*xB3*kappa*vLiIon/sLIFE*(FEM-FET3))
* Remark C (222)
    +z32*y32*q32*( vLiIon/200*( (alphaDRV*muCD3+alphaCHG/effCD3/effBAT)*(FEA3-FEC2)+alphaDRV*muCS3*(FET3-FEA3)
                               +AER3*(alphaDRV*muCD3+alphaCHG/effCD3/effBAT-alphaDRV*muCS3)*(FST3-FSA3) )
                   +1000*xB3*kappa*vLiIon/sLIFE*(FEM-FET3)  )
* Remark D (132 and 1k1)
    +(z31*y33*q32+z31*q31)*( vLiIon/200*(alphaDRV*muCS3*(FEM-FEC2)+
                             AER3*(alphaDRV*muCD3+alphaCHG/effCD3/effBAT-alphaDRV*muCS3)*(FSM-FSC2) )  )
* Remark E (232 and 2k1)
    +(z32*y33*q32+z32*q31)*( vLiIon/200*( (alphaDRV*muCD3+alphaCHG/effCD3/effBAT)*(FEA3-FEC2)
                            +alphaDRV*muCS3*(FEM-FEA3)
                            +AER3*(alphaDRV*muCD3+alphaCHG/effCD3/effBAT-alphaDRV*muCS3)*(FSM-FSA3) ) )
* Remark F (332 and 3k1)
    +(z33*y33*q32+z33*q31)*vLiIon/200*(alphaDRV*muCD3+alphaCHG/effCD3/effBAT)*(FEM-FEC2)  );
*********
f_ghgstot .. ghgstot =e= ghgs1+ghgs2+ghgs3;
*
c_t1  .. t1p+t1h+t1c =e= 1;
c_t2  .. t2p+t2h+t2c =e= 1;
c_t3  .. t3p+t3h+t3c =e= 1;
*
c_sc12 .. sc1 =l= sc2;
* constraints for binary variable sets
c_zz1 .. z11+z12+z13 =e= 1;
c_zz2 .. z21+z22+z23 =e= 1;
c_zz3 .. z31+z32+z33 =e= 1;
c_yy1 .. y11+y12+y13 =e= 1;
c_yy2 .. y21+y22+y23 =e= 1;
c_yy3 .. y31+y32+y33 =e= 1;
c_qq1 .. q11+q12+q13 =e= 1;
c_qq2 .. q21+q22+q23 =e= 1;
c_qq3 .. q31+q32+q33 =e= 1;
*
* constraints on z
c_z11  .. z11*(AER1-0) =l= 0;
c_z12a .. z12*(AER1-0) =g= 0;
c_z12b .. z12*(AER1-sc1) =l= 0;
c_z13  .. z13*(AER1-sc1) =g= 0;
*
c_z21  .. z21*(AER2-sc1) =l= 0;
c_z22a .. z22*(AER2-sc1) =g= 0;
c_z22b .. z22*(AER2-sc2) =l= 0;
c_z23  .. z23*(AER2-sc2) =g= 0;
*
c_z31  .. z31*(AER3-sc2) =l= 0;
c_z32a .. z32*(AER3-sc2) =g= 0;
c_z32b .. z32*(AER3-dMAX) =l= 0;
c_z33  .. z33*(AER3-dMAX) =g= 0;
*
* constraints on y (they only matter when q_2=1)
c_y11  .. q12*y11*(sT1-0) =l= 0;
c_y12a .. q12*y12*(sT1-0) =g= 0;
c_y12b .. q12*y12*(sT1-sc1) =l= 0;
c_y13  .. q12*y13*(sT1-sc1) =g= 0;
*
c_y21  .. q22*y21*(sT2-sc1) =l= 0;
c_y22a .. q22*y22*(sT2-sc1) =g= 0;
c_y22b .. q22*y22*(sT2-sc2) =l= 0;
c_y23  .. q22*y23*(sT2-sc2) =g= 0;
*
c_y31  .. q32*y31*(sT3-sc2) =l= 0;
c_y32a .. q32*y32*(sT3-sc2) =g= 0;
c_y32b .. q32*y32*(sT3-dMAX) =l= 0;
c_y33  .. q32*y33*(sT3-dMAX) =g= 0;
*
* conditional constraints on q
c_q11  .. q11*(1e6*xB1*kappa*rEOL/(alphaDRV*muCS1)-sLIFE) =l= 0;
c_q12a .. q12*(1e6*xB1*kappa*rEOL/(alphaDRV*muCS1)-sLIFE) =g= 0;
c_q13  .. q13*(sLIFE-1e6*xB1*kappa*rEOL/(alphaDRV*muCD1+alphaCHG/effCD1/effBAT)) =l= 0;
c_q12b .. q12*(sLIFE-1e6*xB1*kappa*rEOL/(alphaDRV*muCD1+alphaCHG/effCD1/effBAT)) =g= 0;
*
c_q21  .. q21*(1e6*xB2*kappa*rEOL/(alphaDRV*muCS2)-sLIFE) =l= 0;
c_q22a .. q22*(1e6*xB2*kappa*rEOL/(alphaDRV*muCS2)-sLIFE) =g= 0;
c_q23  .. q23*(sLIFE-1e6*xB2*kappa*rEOL/(alphaDRV*muCD2+alphaCHG/effCD2/effBAT)) =l= 0;
c_q22b .. q22*(sLIFE-1e6*xB2*kappa*rEOL/(alphaDRV*muCD2+alphaCHG/effCD2/effBAT)) =g= 0;
*
c_q31  .. q31*(1e6*xB3*kappa*rEOL/(alphaDRV*muCS3)-sLIFE) =l= 0;
c_q32a .. q32*(1e6*xB3*kappa*rEOL/(alphaDRV*muCS3)-sLIFE) =g= 0;
c_q33  .. q33*(sLIFE-1e6*xB3*kappa*rEOL/(alphaDRV*muCD3+alphaCHG/effCD3/effBAT)) =l= 0;
c_q32b .. q32*(sLIFE-1e6*xB3*kappa*rEOL/(alphaDRV*muCD3+alphaCHG/effCD3/effBAT)) =g= 0;
*
* constraints to exclude infeasible zyq combinations (212),(312),(322)
c_zyq1_212 .. z12+y11+q12 =l= 2;
c_zyq1_312 .. z13+y11+q12 =l= 2;
c_zyq1_322 .. z13+y12+q12 =l= 2;
c_zyq2_212 .. z21+y21+q22 =l= 2;
c_zyq2_312 .. z23+y21+q22 =l= 2;
c_zyq2_322 .. z23+y22+q22 =l= 2;
c_zyq3_212 .. z31+y31+q32 =l= 2;
c_zyq3_312 .. z33+y31+q32 =l= 2;
c_zyq3_322 .. z33+y32+q32 =l= 2;

*
* when (q_1=1 or q_3=1), force y1=1 to save computational time
c_yq13  .. q13*(y11-1) =g= 0;
c_yq11  .. q11*(y11-1) =g= 0;
c_yq23  .. q23*(y21-1) =g= 0;
c_yq21  .. q21*(y21-1) =g= 0;
c_yq33  .. q33*(y31-1) =g= 0;
c_yq31  .. q31*(y31-1) =g= 0;


****
xE1.lo = 30/57;    xE1.up=60/57;    xE1.l=0.7;
xM1.lo = 50/52;    xM1.up=110/52;   xM1.l=1.3;
xB1.lo = 0.2;      xB1.up=1.0;      xB1.l=0.3;
xS1.lo = 0.0;      xS1.up=0.8;      xS1.l=0.8;
*
xE2.lo = 30/57;    xE2.up=60/57;    xE2.l=0.8;
xM2.lo = 50/52;    xM2.up=110/52;   xM2.l=1.3;
xB2.lo = 0.2;      xB2.up=1.0;      xB2.l=0.4;
xS2.lo = 0.0;      xS2.up=0.8;      xS2.l=0.8;
*
xE3.lo = 30/57;    xE3.up=60/57;    xE3.l=0.9;
xM3.lo = 50/52;    xM3.up=110/52;   xM3.l=1.4;
xB3.lo = 0.2;      xB3.up=1.0;      xB3.l=0.5;
xS3.lo = 0.0;      xS3.up=0.8;      xS3.l=0.8;
*
sc1.lo=0; sc1.up=200; sc1.l=30;
sc2.lo=0; sc2.up=200; sc2.l=36;
*
effCD1.lo=4.9;  effCD1.up=5.5;
effCS1.lo=55;   effCS1.up=63;
muCD1.lo=2.2/7.4226;   muCD1.up=3.0/7.4226;
muCS1.lo=1.0/7.4226;   muCS1.up=1.7/7.4226;
socU1.lo=0.26;  socU1.up=0.35;
*
effCD2.lo=4.9;  effCD2.up=5.5;
effCS2.lo=55;   effCS2.up=63;
muCD2.lo=2.2/7.4226;   muCD2.up=3.0/7.4226;
muCS2.lo=1.0/7.4226;   muCS2.up=1.7/7.4226;
socU2.lo=0.26;  socU2.up=0.35;
*
effCD3.lo=4.9;  effCD3.up=5.5;
effCS3.lo=55;   effCS3.up=63;
muCD3.lo=2.2/7.4226;   muCD3.up=3.0/7.4226;
muCS3.lo=1.0/7.4226;   muCS3.up=1.7/7.4226;
socU3.lo=0.26;  socU3.up=0.35;
*
muCD1.l=(aWD1*xE1.l**3+aWD2*xM1.l**3+aWD3*xB1.l**3+aWD4*xE1.l**2*xM1.l+aWD5*xE1.l*xM1.l**2+aWD6*xE1.l**2*xB1.l
     + aWD7*xE1.l*xB1.l**2+aWD8*xM1.l**2*xB1.l+aWD9*xM1.l*xB1.l**2+aWD10*xE1.l*xM1.l*xB1.l
     + aWD11*xE1.l**2+aWD12*xM1.l**2+aWD13*xB1.l**2+aWD14*xE1.l*xM1.l+aWD15*xE1.l*xB1.l+aWD16*xM1.l*xB1.l
     + aWD17*xE1.l+aWD18*xM1.l+aWD19*xB1.l+aWD20)/7.4226;
muCS1.l=(aWS1*xE1.l**3+aWS2*xM1.l**3+aWS3*xB1.l**3+aWS4*xE1.l**2*xM1.l+aWS5*xE1.l*xM1.l**2+aWS6*xE1.l**2*xB1.l
     + aWS7*xE1.l*xB1.l**2+aWS8*xM1.l**2*xB1.l+aWS9*xM1.l*xB1.l**2+aWS10*xE1.l*xM1.l*xB1.l
     + aWS11*xE1.l**2+aWS12*xM1.l**2+aWS13*xB1.l**2+aWS14*xE1.l*xM1.l+aWS15*xE1.l*xB1.l+aWS16*xM1.l*xB1.l
     + aWS17*xE1.l+aWS18*xM1.l+aWS19*xB1.l+aWS20)/7.4226;
effCD1.l = aED1*xE1.l**3+aED2*xM1.l**3+aED3*xB1.l**3+aED4*xE1.l**2*xM1.l+aED5*xE1.l*xM1.l**2+aED6*xE1.l**2*xB1.l
     + aED7*xE1.l*xB1.l**2+aED8*xM1.l**2*xB1.l+aED9*xM1.l*xB1.l**2+aED10*xE1.l*xM1.l*xB1.l
     + aED11*xE1.l**2+aED12*xM1.l**2+aED13*xB1.l**2+aED14*xE1.l*xM1.l+aED15*xE1.l*xB1.l+aED16*xM1.l*xB1.l
     + aED17*xE1.l+aED18*xM1.l+aED19*xB1.l+aED20;
effCS1.l = aES1*xE1.l**3+aES2*xM1.l**3+aES3*xB1.l**3+aES4*xE1.l**2*xM1.l+aES5*xE1.l*xM1.l**2+aES6*xE1.l**2*xB1.l
     + aES7*xE1.l*xB1.l**2+aES8*xM1.l**2*xB1.l+aES9*xM1.l*xB1.l**2+aES10*xE1.l*xM1.l*xB1.l
     + aES11*xE1.l**2+aES12*xM1.l**2+aES13*xB1.l**2+aES14*xE1.l*xM1.l+aES15*xE1.l*xB1.l+aES16*xM1.l*xB1.l
     + aES17*xE1.l+aES18*xM1.l+aES19*xB1.l+aES20;
socU1.l = aU1*xE1.l**3+aU2*xM1.l**3+aU3*xB1.l**3+aU4*xE1.l**2*xM1.l+aU5*xE1.l*xM1.l**2+aU6*xE1.l**2*xB1.l
       + aU7*xE1.l*xB1.l**2+aU8*xM1.l**2*xB1.l+aU9*xM1.l*xB1.l**2+aU10*xE1.l*xM1.l*xB1.l
       + aU11*xE1.l**2+aU12*xM1.l**2+aU13*xB1.l**2+aU14*xE1.l*xM1.l+aU15*xE1.l*xB1.l+aU16*xM1.l*xB1.l
       + aU17*xE1.l+aU18*xM1.l+aU19*xB1.l+aU20;
tAD1.l = aAD1*xE1.l**3+aAD2*xM1.l**3+aAD3*xB1.l**3+aAD4*xE1.l**2*xM1.l+aAD5*xE1.l*xM1.l**2+aAD6*xE1.l**2*xB1.l
       + aAD7*xE1.l*xB1.l**2+aAD8*xM1.l**2*xB1.l+aAD9*xM1.l*xB1.l**2+aAD10*xE1.l*xM1.l*xB1.l
       + aAD11*xE1.l**2+aAD12*xM1.l**2+aAD13*xB1.l**2+aAD14*xE1.l*xM1.l+aAD15*xE1.l*xB1.l+aAD16*xM1.l*xB1.l
       + aAD17*xE1.l+aAD18*xM1.l+aAD19*xB1.l+aAD20;
tAS1.l = aAS1*xE1.l**3+aAS2*xM1.l**3+aAS3*xB1.l**3+aAS4*xE1.l**2*xM1.l+aAS5*xE1.l*xM1.l**2+aAS6*xE1.l**2*xB1.l
       + aAS7*xE1.l*xB1.l**2+aAS8*xM1.l**2*xB1.l+aAS9*xM1.l*xB1.l**2+aAS10*xE1.l*xM1.l*xB1.l
       + aAS11*xE1.l**2+aAS12*xM1.l**2+aAS13*xB1.l**2+aAS14*xE1.l*xM1.l+aAS15*xE1.l*xB1.l+aAS16*xM1.l*xB1.l
       + aAS17*xE1.l+aAS18*xM1.l+aAS19*xB1.l+aAS20;
*
muCD2.l=(aWD1*xE2.l**3+aWD2*xM2.l**3+aWD3*xB2.l**3+aWD4*xE2.l**2*xM2.l+aWD5*xE2.l*xM2.l**2+aWD6*xE2.l**2*xB2.l
     + aWD7*xE2.l*xB2.l**2+aWD8*xM2.l**2*xB2.l+aWD9*xM2.l*xB2.l**2+aWD10*xE2.l*xM2.l*xB2.l
     + aWD11*xE2.l**2+aWD12*xM2.l**2+aWD13*xB2.l**2+aWD14*xE2.l*xM2.l+aWD15*xE2.l*xB2.l+aWD16*xM2.l*xB2.l
     + aWD17*xE2.l+aWD18*xM2.l+aWD19*xB2.l+aWD20)/7.4226;
muCS2.l=(aWS1*xE2.l**3+aWS2*xM2.l**3+aWS3*xB2.l**3+aWS4*xE2.l**2*xM2.l+aWS5*xE2.l*xM2.l**2+aWS6*xE2.l**2*xB2.l
     + aWS7*xE2.l*xB2.l**2+aWS8*xM2.l**2*xB2.l+aWS9*xM2.l*xB2.l**2+aWS10*xE2.l*xM2.l*xB2.l
     + aWS11*xE2.l**2+aWS12*xM2.l**2+aWS13*xB2.l**2+aWS14*xE2.l*xM2.l+aWS15*xE2.l*xB2.l+aWS16*xM2.l*xB2.l
     + aWS17*xE2.l+aWS18*xM2.l+aWS19*xB2.l+aWS20)/7.4226;
effCD2.l = aED1*xE2.l**3+aED2*xM2.l**3+aED3*xB2.l**3+aED4*xE2.l**2*xM2.l+aED5*xE2.l*xM2.l**2+aED6*xE2.l**2*xB2.l
     + aED7*xE2.l*xB2.l**2+aED8*xM2.l**2*xB2.l+aED9*xM2.l*xB2.l**2+aED10*xE2.l*xM2.l*xB2.l
     + aED11*xE2.l**2+aED12*xM2.l**2+aED13*xB2.l**2+aED14*xE2.l*xM2.l+aED15*xE2.l*xB2.l+aED16*xM2.l*xB2.l
     + aED17*xE2.l+aED18*xM2.l+aED19*xB2.l+aED20;
effCS2.l = aES1*xE2.l**3+aES2*xM2.l**3+aES3*xB2.l**3+aES4*xE2.l**2*xM2.l+aES5*xE2.l*xM2.l**2+aES6*xE2.l**2*xB2.l
     + aES7*xE2.l*xB2.l**2+aES8*xM2.l**2*xB2.l+aES9*xM2.l*xB2.l**2+aES10*xE2.l*xM2.l*xB2.l
     + aES11*xE2.l**2+aES12*xM2.l**2+aES13*xB2.l**2+aES14*xE2.l*xM2.l+aES15*xE2.l*xB2.l+aES16*xM2.l*xB2.l
     + aES17*xE2.l+aES18*xM2.l+aES19*xB2.l+aES20;
socU2.l = aU1*xE2.l**3+aU2*xM2.l**3+aU3*xB2.l**3+aU4*xE2.l**2*xM2.l+aU5*xE2.l*xM2.l**2+aU6*xE2.l**2*xB2.l
       + aU7*xE2.l*xB2.l**2+aU8*xM2.l**2*xB2.l+aU9*xM2.l*xB2.l**2+aU10*xE2.l*xM2.l*xB2.l
       + aU11*xE2.l**2+aU12*xM2.l**2+aU13*xB2.l**2+aU14*xE2.l*xM2.l+aU15*xE2.l*xB2.l+aU16*xM2.l*xB2.l
       + aU17*xE2.l+aU18*xM2.l+aU19*xB2.l+aU20;
tAD2.l = aAD1*xE2.l**3+aAD2*xM2.l**3+aAD3*xB2.l**3+aAD4*xE2.l**2*xM2.l+aAD5*xE2.l*xM2.l**2+aAD6*xE2.l**2*xB2.l
       + aAD7*xE2.l*xB2.l**2+aAD8*xM2.l**2*xB2.l+aAD9*xM2.l*xB2.l**2+aAD10*xE2.l*xM2.l*xB2.l
       + aAD11*xE2.l**2+aAD12*xM2.l**2+aAD13*xB2.l**2+aAD14*xE2.l*xM2.l+aAD15*xE2.l*xB2.l+aAD16*xM2.l*xB2.l
       + aAD17*xE2.l+aAD18*xM2.l+aAD19*xB2.l+aAD20;
tAS2.l = aAS1*xE2.l**3+aAS2*xM2.l**3+aAS3*xB2.l**3+aAS4*xE2.l**2*xM2.l+aAS5*xE2.l*xM2.l**2+aAS6*xE2.l**2*xB2.l
       + aAS7*xE2.l*xB2.l**2+aAS8*xM2.l**2*xB2.l+aAS9*xM2.l*xB2.l**2+aAS10*xE2.l*xM2.l*xB2.l
       + aAS11*xE2.l**2+aAS12*xM2.l**2+aAS13*xB2.l**2+aAS14*xE2.l*xM2.l+aAS15*xE2.l*xB2.l+aAS16*xM2.l*xB2.l
       + aAS17*xE2.l+aAS18*xM2.l+aAS19*xB2.l+aAS20;
*
muCD3.l=(aWD1*xE3.l**3+aWD2*xM3.l**3+aWD3*xB3.l**3+aWD4*xE3.l**2*xM3.l+aWD5*xE3.l*xM3.l**2+aWD6*xE3.l**2*xB3.l
     + aWD7*xE3.l*xB3.l**2+aWD8*xM3.l**2*xB3.l+aWD9*xM3.l*xB3.l**2+aWD10*xE3.l*xM3.l*xB3.l
     + aWD11*xE3.l**2+aWD12*xM3.l**2+aWD13*xB3.l**2+aWD14*xE3.l*xM3.l+aWD15*xE3.l*xB3.l+aWD16*xM3.l*xB3.l
     + aWD17*xE3.l+aWD18*xM3.l+aWD19*xB3.l+aWD20)/7.4226;
muCS3.l=(aWS1*xE3.l**3+aWS2*xM3.l**3+aWS3*xB3.l**3+aWS4*xE3.l**2*xM3.l+aWS5*xE3.l*xM3.l**2+aWS6*xE3.l**2*xB3.l
     + aWS7*xE3.l*xB3.l**2+aWS8*xM3.l**2*xB3.l+aWS9*xM3.l*xB3.l**2+aWS10*xE3.l*xM3.l*xB3.l
     + aWS11*xE3.l**2+aWS12*xM3.l**2+aWS13*xB3.l**2+aWS14*xE3.l*xM3.l+aWS15*xE3.l*xB3.l+aWS16*xM3.l*xB3.l
     + aWS17*xE3.l+aWS18*xM3.l+aWS19*xB3.l+aWS20)/7.4226;
effCD3.l = aED1*xE3.l**3+aED2*xM3.l**3+aED3*xB3.l**3+aED4*xE3.l**2*xM3.l+aED5*xE3.l*xM3.l**2+aED6*xE3.l**2*xB3.l
     + aED7*xE3.l*xB3.l**2+aED8*xM3.l**2*xB3.l+aED9*xM3.l*xB3.l**2+aED10*xE3.l*xM3.l*xB3.l
     + aED11*xE3.l**2+aED12*xM3.l**2+aED13*xB3.l**2+aED14*xE3.l*xM3.l+aED15*xE3.l*xB3.l+aED16*xM3.l*xB3.l
     + aED17*xE3.l+aED18*xM3.l+aED19*xB3.l+aED20;
effCS3.l = aES1*xE3.l**3+aES2*xM3.l**3+aES3*xB3.l**3+aES4*xE3.l**2*xM3.l+aES5*xE3.l*xM3.l**2+aES6*xE3.l**2*xB3.l
     + aES7*xE3.l*xB3.l**2+aES8*xM3.l**2*xB3.l+aES9*xM3.l*xB3.l**2+aES10*xE3.l*xM3.l*xB3.l
     + aES11*xE3.l**2+aES12*xM3.l**2+aES13*xB3.l**2+aES14*xE3.l*xM3.l+aES15*xE3.l*xB3.l+aES16*xM3.l*xB3.l
     + aES17*xE3.l+aES18*xM3.l+aES19*xB3.l+aES20;
socU3.l = aU1*xE3.l**3+aU2*xM3.l**3+aU3*xB3.l**3+aU4*xE3.l**2*xM3.l+aU5*xE3.l*xM3.l**2+aU6*xE3.l**2*xB3.l
       + aU7*xE3.l*xB3.l**2+aU8*xM3.l**2*xB3.l+aU9*xM3.l*xB3.l**2+aU10*xE3.l*xM3.l*xB3.l
       + aU11*xE3.l**2+aU12*xM3.l**2+aU13*xB3.l**2+aU14*xE3.l*xM3.l+aU15*xE3.l*xB3.l+aU16*xM3.l*xB3.l
       + aU17*xE3.l+aU18*xM3.l+aU19*xB3.l+aU20;
tAD3.l = aAD1*xE3.l**3+aAD2*xM3.l**3+aAD3*xB3.l**3+aAD4*xE3.l**2*xM3.l+aAD5*xE3.l*xM3.l**2+aAD6*xE3.l**2*xB3.l
       + aAD7*xE3.l*xB3.l**2+aAD8*xM3.l**2*xB3.l+aAD9*xM3.l*xB3.l**2+aAD10*xE3.l*xM3.l*xB3.l
       + aAD11*xE3.l**2+aAD12*xM3.l**2+aAD13*xB3.l**2+aAD14*xE3.l*xM3.l+aAD15*xE3.l*xB3.l+aAD16*xM3.l*xB3.l
       + aAD17*xE3.l+aAD18*xM3.l+aAD19*xB3.l+aAD20;
tAS3.l = aAS1*xE3.l**3+aAS2*xM3.l**3+aAS3*xB3.l**3+aAS4*xE3.l**2*xM3.l+aAS5*xE3.l*xM3.l**2+aAS6*xE3.l**2*xB3.l
       + aAS7*xE3.l*xB3.l**2+aAS8*xM3.l**2*xB3.l+aAS9*xM3.l*xB3.l**2+aAS10*xE3.l*xM3.l*xB3.l
       + aAS11*xE3.l**2+aAS12*xM3.l**2+aAS13*xB3.l**2+aAS14*xE3.l*xM3.l+aAS15*xE3.l*xB3.l+aAS16*xM3.l*xB3.l
       + aAS17*xE3.l+aAS18*xM3.l+aAS19*xB3.l+aAS20;
*
AER1.l=kappa*1000*xB1.l*xS1.l*effCD1.l; AER1.up=90;
AER2.l=kappa*1000*xB2.l*xS2.l*effCD2.l; AER2.up=90;
AER3.l=kappa*1000*xB3.l*xS3.l*effCD3.l; AER3.up=90;
*
FEA1.l=1/k-exp(-1*k*AER1.l)*(AER1.l+1/k); FEA1.up=26;
FSA1.l=1-exp(-1*k*AER1.l); FSA1.up=1;
FEA2.l=1/k-exp(-1*k*AER2.l)*(AER2.l+1/k); FEA2.up=26;
FSA2.l=1-exp(-1*k*AER2.l); FSA2.up=1;
FEA3.l=1/k-exp(-1*k*AER3.l)*(AER3.l+1/k); FEA3.up=26;
FSA3.l=1-exp(-1*k*AER3.l); FSA3.up=1;
*
sT1.l =sLIFE*AER1.l*(alphaDRV*muCD1.l+alphaCHG/effCD1.l/effBAT-alphaDRV*muCS1.l)
                   /(0.2*kappa*1e6*xB1.l-alphaDRV*muCS1.l*sLIFE);
sT2.l =sLIFE*AER2.l*(alphaDRV*muCD2.l+alphaCHG/effCD2.l/effBAT-alphaDRV*muCS2.l)
                   /(0.2*kappa*1e6*xB2.l-alphaDRV*muCS2.l*sLIFE);
sT3.l =sLIFE*AER3.l*(alphaDRV*muCD3.l+alphaCHG/effCD3.l/effBAT-alphaDRV*muCS3.l)
                   /(0.2*kappa*1e6*xB3.l-alphaDRV*muCS3.l*sLIFE);
sT1.up=200; sT2.up=200;  sT3.up=200;
*
FEC1.l=1/k-exp(-1*k*SC1.l)*(SC1.l+1/k); FEC1.up=34.1;
FSC1.l=1-exp(-1*k*SC1.l); FSC1.up=1;
*
FEC2.l=1/k-exp(-1*k*SC2.l)*(SC2.l+1/k); FEC2.up=34.1;
FSC2.l=1-exp(-1*k*SC2.l); FSC2.up=1;
*
FET1.l=1/k-exp(-1*k*sT1.l)*(sT1.l+1/k); FET1.up=34.1;
FST1.l=1-exp(-1*k*sT1.l); FST1.up=1;
*
FET2.l=1/k-exp(-1*k*sT2.l)*(sT2.l+1/k); FET2.up=34.1;
FST2.l=1-exp(-1*k*sT2.l); FST2.up=1;
*
FET3.l=1/k-exp(-1*k*sT3.l)*(sT3.l+1/k); FET3.up=34.1;
FST3.l=1-exp(-1*k*sT3.l); FST3.up=1;
*
tAD1.up=13;  tAD1.lo=6;
tAS1.up=13;  tAS1.lo=6;
*
tAD2.up=13;  tAD2.lo=6;
tAS2.up=13;  tAS2.lo=6;
*
tAD3.up=13;  tAD3.lo=6;
tAS3.up=13;  tAS3.lo=6;
*
z11.l=0; z12.l=1; z13.l=0;
y11.l=0; y12.l=1; y13.l=0;
q11.l=0; q12.l=1; q13.l=0;
*
z21.l=0; z22.l=1; z23.l=0;
y21.l=0; y22.l=1; y23.l=0;
q21.l=0; q22.l=1; q23.l=0;
*
z31.l=0; z32.l=1; z33.l=0;
y31.l=0; y32.l=1; y33.l=0;
q31.l=0; q32.l=1; q33.l=0;
*
* note: exclude CV and fix VEH#1=PHEV to save computational time
t1p.fx=1;  t1h.fx=0;  t1c.fx=0;
t2p.fx=1;  t2h.fx=0;  t2c.fx=0;
t3p.fx=1;  t3h.fx=0;  t3c.fx=0;
*
model PHEV /all/;
*$onecho > baron.opt
*ConTol=1E-6
*EpsA=1E-6
*EpsR=0
*MaxTime=45000
*nlpsol=4
*$offecho
PHEV.optfile=1;
option MINLP=BARON;
solve PHEV using MINLP min ghgstot;

****** post-process
****** display in the log file
file log / '' /;
put log;
put ' ' /;
put 'Optimal 3-vehicle designs and allocations for min-GHGs' /;
put 'Peterson battery model with buy-lease scenario (PB)' /;
put '------------------------------------------------' /;
put 'Parameters:' /;
put 'Li-ion Battery GHGs = ',(vLiIon):4:0,' kg-CO2-eq/kWh' /;
put '  NiMH Battery GHGs = ',(vNiMH):4:0,' kg-CO2-eq/kWh' /;
put '        Gas GHGs = ',(vGAS):5:2, ' kg-CO2-eq/gal' /;
put 'Electricity GHGs = ',(vELEC):6:4,' kg-CO2-eq/kWh' /;
put '------------------------------------------------' /;
if (t1p.l=1,
   put 'VEHICLE-1 is a PHEV',(AER1.l):3:0 /;
   put '-----------------------' /;
   put '   All Elec Range    AER = ',(AER1.l):6:2,' miles' /;
   put '   Engine scale       xE = ',(xE1.l):6:4,' (',(xE1.l*57):5:1,' kW)'/;
   put '   Motor scale        xM = ',(xM1.l):6:4,' (',(xM1.l*52):5:1,' kW)'/;
   put '   Battery scale      xB = ',(xB1.l):6:4,' (',(xB1.l*1000):4:0,' cells)'/;
   put '   Design swing       xS = ',(xS1.l):6:4 /;
   put '   CD efficiency  eff.CD = ',(effCD1.l):6:2,' mile/kWh' /;
   put '   CS efficiency  eff.CS = ',(effCS1.l):6:2,' mile/gal' /;
   put '   CD acceleration  t.CD = ',(tAD1.l):6:2,' secs' /;
   put '   CS acceleration  t.CS = ',(tAS1.l):6:2,' secs' /;
   put '   Battery energy cap.   = ',(xB1.l*1000*kappa):6:3  ' kWh' /;
   put '   Final SOC after 4US06 = ',(SOCU1.l):6:3 /;
   put '   VEH-BAT life point sT = ',(sT1.l):7:3,' miles'/;
   put '           theta_BAT_INF = ',(1e6*xB1.l*kappa*rEOL/(alphaDRV*muCS1.l)):7:0 /;
   put '           theta_BAT_0   = ',(1e6*xB1.l*kappa*rEOL/(alphaDRV*muCD1.l+alphaCHG/effCD1.l/effBAT)):7:0 /;
elseif (t1h.l=1),
   put 'VEHICLE-1 is a HEV' /;
   put '---------------------' /;
elseif (t1c.l=1),
   put 'VEHICLE-1 is a CV' /;
   put '---------------------' /;
else
   put 'VEHICLE-1 is not identified' /;
) ;
put '   Total lifecycle GHGs  = ',(ghgs1.l):9:6,' kg-CO2-eq/person-day'/;
put '------------------------------------------------' /;
*
if (t2p.l=1,
   put 'VEHICLE-2 is a PHEV',(AER2.l):3:0 /;
   put '-----------------------' /;
   put '   All Elec Range    AER = ',(AER2.l):6:2,' miles' /;
   put '   Engine scale       xE = ',(xE2.l):6:4,' (',(xE2.l*57):5:1,' kW)'/;
   put '   Motor scale        xM = ',(xM2.l):6:4,' (',(xM2.l*52):5:1,' kW)'/;
   put '   Battery scale      xB = ',(xB2.l):6:4,' (',(xB2.l*1000):4:0,' cells)'/;
   put '   Design swing       xS = ',(xS2.l):6:4 /;
   put '   CD efficiency  eff.CD = ',(effCD2.l):6:2,' mile/kWh' /;
   put '   CS efficiency  eff.CS = ',(effCS2.l):6:2,' mile/gal' /;
   put '   CD acceleration  t.CD = ',(tAD2.l):6:2,' secs' /;
   put '   CS acceleration  t.CS = ',(tAS2.l):6:2,' secs' /;
   put '        Battery capacity = ',(xB2.l*1000*kappa):6:3  ' kWh' /;
   put '   Final SOC after 4US06 = ',(SOCU2.l):6:3 /;
   put ' VEH-BAT intersection sT = ',(sT2.l):7:3,' miles'/;
   put '           theta_BAT_INF = ',(1e6*xB2.l*kappa*rEOL/(alphaDRV*muCS2.l)):7:0 /;
   put '           theta_BAT_0   = ',(1e6*xB2.l*kappa*rEOL/(alphaDRV*muCD2.l+alphaCHG/effCD2.l/effBAT)):7:0 /;
elseif (t2h.l=1),
   put 'VEHICLE-2 is a HEV' /;
   put '---------------------' /;
elseif (t2c.l=1),
   put 'VEHICLE-2 is a CV' /;
   put '---------------------' /;
else
   put 'VEHICLE-2 is not identified' /;
);
put '   Total lifecycle GHGs  = ',(ghgs2.l):9:6,' kg-CO2-eq/person-day'/;
put '------------------------------------------------' /;
*
if (t3p.l=1,
   put 'VEHICLE-3 is a PHEV',(AER3.l):3:0 /;
   put '-----------------------' /;
   put '   All Elec Range    AER = ',(AER3.l):6:2,' miles' /;
   put '   Engine scale       xE = ',(xE3.l):6:4,' (',(xE3.l*57):5:1,' kW)'/;
   put '   Motor scale        xM = ',(xM3.l):6:4,' (',(xM3.l*52):5:1,' kW)'/;
   put '   Battery scale      xB = ',(xB3.l):6:4,' (',(xB3.l*1000):4:0,' cells)'/;
   put '   Design swing       xS = ',(xS3.l):6:4 /;
   put '   CD efficiency  eff.CD = ',(effCD3.l):6:2,' mile/kWh' /;
   put '   CS efficiency  eff.CS = ',(effCS3.l):6:2,' mile/gal' /;
   put '   CD acceleration  t.CD = ',(tAD3.l):6:2,' secs' /;
   put '   CS acceleration  t.CS = ',(tAS3.l):6:2,' secs' /;
   put '   Battery energy cap.   = ',(xB3.l*1000*kappa):6:3  ' kWh' /;
   put '   Final SOC after 4US06 = ',(SOCU3.l):6:3 /;
   put '   VEH-BAT life point sT = ',(sT3.l):7:3,' miles'/;
   put '           theta_BAT_INF = ',(1e6*xB3.l*kappa*rEOL/(alphaDRV*muCS3.l)):7:0 /;
   put '           theta_BAT_0   = ',(1e6*xB3.l*kappa*rEOL/(alphaDRV*muCD3.l+alphaCHG/effCD3.l/effBAT)):7:0 /;
elseif (t3h.l=1),
   put 'VEHICLE-3 is a HEV' /;
   put '---------------------' /;
elseif (t3c.l=1),
   put 'VEHICLE-3 is a CV' /;
   put '---------------------' /;
else
   put 'VEHICLE-3 is not identified' /;
);
put '   Total lifecycle GHGs  = ',(ghgs3.l):9:6,' kg-CO2-eq/person-day'/;
put '------------------------------------------------' /;
put '   Cutoff distance #1    = ',(sc1.l):7:3,' miles' /;
put '   Cutoff distance #2    = ',(sc2.l):7:3,' miles' /;
put '   Total lifecycle GHGs  = ',(ghgstot.l):9:12,' kg-CO2-eq/person-day'/;
put '------------------------------------------------' /;
put ' ' /;
put (xE1.l):16:12 /;
put (xM1.l):16:12 /;
put (xB1.l):16:12 /;
put (xS1.l):16:12 /;
put (xE2.l):16:12 /;
put (xM2.l):16:12 /;
put (xB2.l):16:12 /;
put (xS2.l):16:12 /;
put (xE3.l):16:12 /;
put (xM3.l):16:12 /;
put (xB3.l):16:12 /;
put (xS3.l):16:12 /;
put (sc1.l/100):16:12 /;
put (sc2.l/100):16:12 /;
put ' ' /;
